@@ -21,8 +21,6 @@ import org.eclipse.e4.ui.css.swt.helpers.CSSSWTColorHelper;
 import org.eclipse.e4.ui.css.swt.helpers.SWTElementHelpers;
 import org.eclipse.swt.custom.CTabFolder;
 import org.eclipse.swt.custom.CTabItem;
-import org.eclipse.swt.events.VerifyEvent;
-import org.eclipse.swt.events.VerifyListener;
 import org.eclipse.swt.graphics.Color;
 import org.eclipse.swt.widgets.Button;
 import org.eclipse.swt.widgets.Control;
@@ -40,8 +38,7 @@ public class CSSPropertyTextSWTHandler extends AbstractCSSPropertyTextHandler {
 			CSSValue value, String pseudo, CSSEngine engine) throws Exception {
 		Widget widget = SWTElementHelpers.getWidget(element);
 		if (widget != null) {
-			super.applyCSSProperty(widget, property, value, pseudo, engine);
-			return true;
+			return super.applyCSSProperty(widget, property, value, pseudo, engine);
 		}
 		return false;
 
@@ -61,23 +58,21 @@ public class CSSPropertyTextSWTHandler extends AbstractCSSPropertyTextHandler {
 	public void applyCSSPropertyColor(Object element, CSSValue value,
 			String pseudo, CSSEngine engine) throws Exception {
 		Widget widget = (Widget) element;
-		if (value.getCssValueType() == CSSValue.CSS_PRIMITIVE_VALUE) {
-			Color newColor = (Color) engine.convert(value, Color.class, widget
-					.getDisplay());
-			if (newColor != null && newColor.isDisposed()) {
-				return;
-			}
+		Color newColor = (Color) engine.convert(value, Color.class, widget.getDisplay());
 
-			if (widget instanceof CTabItem) {
-				CTabFolder folder = ((CTabItem) widget).getParent();
-				if ("selected".equals(pseudo)) {
-					CSSSWTColorHelper.setSelectionForeground(folder, newColor);
-				} else {
-					CSSSWTColorHelper.setForeground(folder, newColor);
-				}
-			} else if (widget instanceof Control) {
-				CSSSWTColorHelper.setForeground((Control) widget, newColor);
+		if (newColor != null && newColor.isDisposed() || value.getCssValueType() != CSSValue.CSS_PRIMITIVE_VALUE) {
+			return;
+		}
+
+		if (widget instanceof CTabItem) {
+			CTabFolder folder = ((CTabItem) widget).getParent();
+			if ("selected".equals(pseudo)) {
+				CSSSWTColorHelper.setSelectionForeground(folder, newColor);
+			} else {
+				CSSSWTColorHelper.setForeground(folder, newColor);
 			}
+		} else if (widget instanceof Control) {
+			CSSSWTColorHelper.setForeground((Control) widget, newColor);
 		}
 	}
 
@@ -89,30 +84,6 @@ public class CSSPropertyTextSWTHandler extends AbstractCSSPropertyTextHandler {
 		String defaultText = (String) widget.getData(CSSSWTConstants.TEXT_KEY);
 		if (element instanceof Text) {
 			final Text text = (Text) widget;
-			VerifyListener listener = (VerifyListener) text
-					.getData("CSSModifyTextListener");
-			if (hasTextTransform(value)) {
-				if (listener == null) {
-					// Add ModifyListener
-					listener = new VerifyListener() {
-						@Override
-						public void verifyText(VerifyEvent e) {
-							// System.out.println(e);
-							// int start = e.start;
-							// int end = e.end;
-							// e.text = getTextTransform(e.text, text.getText(),
-							// value);
-						}
-					};
-					text.addVerifyListener(listener);
-					text.setData("CSSModifyTextListener", listener);
-				}
-			} else {
-				if (listener != null) {
-					text.removeVerifyListener(listener);
-					text.setData("CSSModifyTextListener", null);
-				}
-			}
 			String oldText = text.getText();
 			String newText = getTextTransform(text.getText(), value,
 					defaultText);
@@ -166,12 +137,10 @@ public class CSSPropertyTextSWTHandler extends AbstractCSSPropertyTextHandler {
 			if (text != null) {
 				widget.setData(CSSSWTConstants.TEXT_KEY, text);
 			}
-		} else {
-			if (widget instanceof Button) {
-				text = ((Button) element).getText();
-				if (text != null) {
-					widget.setData(CSSSWTConstants.TEXT_KEY, text);
-				}
+		} else if (widget instanceof Button) {
+			text = ((Button) element).getText();
+			if (text != null) {
+				widget.setData(CSSSWTConstants.TEXT_KEY, text);
 			}
 		}
 		// }
