@@ -15,11 +15,11 @@
  *******************************************************************************/
 package org.eclipse.e4.ui.dialogs.filteredtree;
 
-import java.util.ArrayList;
 import java.util.HashMap;
-import java.util.List;
 import java.util.Map;
+import java.util.regex.Pattern;
 
+import org.eclipse.core.text.StringMatcher;
 import org.eclipse.jface.viewers.AbstractTreeViewer;
 import org.eclipse.jface.viewers.CellLabelProvider;
 import org.eclipse.jface.viewers.ColumnViewer;
@@ -33,10 +33,10 @@ import org.eclipse.jface.viewers.StyledString;
 import org.eclipse.jface.viewers.Viewer;
 import org.eclipse.jface.viewers.ViewerFilter;
 
-import com.ibm.icu.text.BreakIterator;
-
 /**
  * Based on org.eclipse.ui.dialogs.PatternFilter.
+ *
+ * @since 1.2
  */
 public class PatternFilter extends ViewerFilter {
 	/*
@@ -66,6 +66,8 @@ public class PatternFilter extends ViewerFilter {
 
 	private static Object[] EMPTY = new Object[0];
 
+	private static final Pattern NON_WORD = Pattern.compile("\\W+", Pattern.UNICODE_CHARACTER_CLASS); //$NON-NLS-1$
+
 	public PatternFilter() {
 	}
 
@@ -343,31 +345,7 @@ public class PatternFilter extends ViewerFilter {
 	 * @return an array of words
 	 */
 	private String[] getWords(String text) {
-		List<String> words = new ArrayList<>();
-		// Break the text up into words, separating based on whitespace and
-		// common punctuation.
-		// Previously used String.split(..., "\\W"), where "\W" is a regular
-		// expression (see the Javadoc for class Pattern).
-		// Need to avoid both String.split and regular expressions, in order to
-		// compile against JCL Foundation (bug 80053).
-		// Also need to do this in an NL-sensitive way. The use of BreakIterator
-		// was suggested in bug 90579.
-		BreakIterator iter = BreakIterator.getWordInstance();
-		iter.setText(text);
-		int i = iter.first();
-		while (i != java.text.BreakIterator.DONE && i < text.length()) {
-			int j = iter.following(i);
-			if (j == java.text.BreakIterator.DONE) {
-				j = text.length();
-			}
-			// match the word
-			if (Character.isLetterOrDigit(text.charAt(i))) {
-				String word = text.substring(i, j);
-				words.add(word);
-			}
-			i = j;
-		}
-		return words.toArray(new String[words.size()]);
+		return NON_WORD.split(text, 0);
 	}
 
 	/**
