@@ -985,61 +985,59 @@ public class PartServiceImpl implements EPartService {
 			if (category == null) {
 				// no category, just add it to the end
 				addToLastContainer(null, providedPart);
-			} else {
-				if ("org.eclipse.e4.primaryDataStack".equals(category)) { //$NON-NLS-1$
-					MElementContainer<? extends MUIElement> container = getContainer();
-					MUIElement area = modelService.find("org.eclipse.ui.editorss", container); //$NON-NLS-1$
+			} else if ("org.eclipse.e4.primaryDataStack".equals(category)) { //$NON-NLS-1$
+				MElementContainer<? extends MUIElement> container = getContainer();
+				MUIElement area = modelService.find("org.eclipse.ui.editorss", container); //$NON-NLS-1$
 
-					MPartStack activeStack = null;
-					if (area instanceof MPlaceholder
-							&& ((MPlaceholder) area).getRef() instanceof MArea) {
-						// Find the currently 'active' stack in the area
-						MArea a = (MArea) ((MPlaceholder) area).getRef();
-						MUIElement curActive = a.getSelectedElement();
-						while (curActive instanceof MElementContainer<?>) {
-							if (curActive instanceof MPartStack) {
-								activeStack = (MPartStack) curActive;
+				MPartStack activeStack = null;
+				if (area instanceof MPlaceholder
+						&& ((MPlaceholder) area).getRef() instanceof MArea) {
+					// Find the currently 'active' stack in the area
+					MArea a = (MArea) ((MPlaceholder) area).getRef();
+					MUIElement curActive = a.getSelectedElement();
+					while (curActive instanceof MElementContainer<?>) {
+						if (curActive instanceof MPartStack) {
+							activeStack = (MPartStack) curActive;
+							break;
+						}
+						MElementContainer<?> curContainer = (MElementContainer<?>) curActive;
+						curActive = curContainer.getSelectedElement();
+					}
+				}
+
+				if (activeStack != null) {
+					activeStack.getChildren().add(providedPart);
+				} else {
+					// Find the first visible stack in the area
+					List<MPartStack> sharedStacks = modelService.findElements(area, null, MPartStack.class);
+					if (sharedStacks.size() > 0) {
+						for (MPartStack stack : sharedStacks) {
+							if (stack.isToBeRendered()) {
+								stack.getChildren().add(providedPart);
 								break;
 							}
-							MElementContainer<?> curContainer = (MElementContainer<?>) curActive;
-							curActive = curContainer.getSelectedElement();
 						}
-					}
-
-					if (activeStack != null) {
-						activeStack.getChildren().add(providedPart);
 					} else {
-						// Find the first visible stack in the area
-						List<MPartStack> sharedStacks = modelService.findElements(area, null, MPartStack.class);
-						if (sharedStacks.size() > 0) {
-							for (MPartStack stack : sharedStacks) {
-								if (stack.isToBeRendered()) {
-									stack.getChildren().add(providedPart);
-									break;
-								}
-							}
-						} else {
-							addToLastContainer(null, providedPart);
-						}
+						addToLastContainer(null, providedPart);
 					}
+				}
+			} else {
+				@SuppressWarnings("rawtypes")
+				List<MElementContainer> containers = modelService.findElements(getContainer(),
+						null, MElementContainer.class, Collections.singletonList(category),
+						EModelService.PRESENTATION);
+				if (containers.isEmpty()) {
+					// couldn't find any containers with the specified tag, just add it to the
+					// end
+					addToLastContainer(category, providedPart);
 				} else {
-					@SuppressWarnings("rawtypes")
-					List<MElementContainer> containers = modelService.findElements(getContainer(),
-							null, MElementContainer.class, Collections.singletonList(category),
-							EModelService.PRESENTATION);
-					if (containers.isEmpty()) {
-						// couldn't find any containers with the specified tag, just add it to the
-						// end
-						addToLastContainer(category, providedPart);
+					// add the part to the container
+					MElementContainer<MPartSashContainerElement> container = containers.get(0);
+					MPlaceholder placeholder = providedPart.getCurSharedRef();
+					if (placeholder == null) {
+						container.getChildren().add(providedPart);
 					} else {
-						// add the part to the container
-						MElementContainer<MPartSashContainerElement> container = containers.get(0);
-						MPlaceholder placeholder = providedPart.getCurSharedRef();
-						if (placeholder == null) {
-							container.getChildren().add(providedPart);
-						} else {
-							container.getChildren().add(placeholder);
-						}
+						container.getChildren().add(placeholder);
 					}
 				}
 			}
