@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2008, 2015 Matthew Hall and others.
+ * Copyright (c) 2008, 2020 Matthew Hall and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -17,6 +17,8 @@
 
 package org.eclipse.jface.databinding.swt.typed;
 
+import java.time.LocalDate;
+import java.time.LocalTime;
 import java.util.Date;
 
 import org.eclipse.jface.databinding.swt.IWidgetListProperty;
@@ -31,9 +33,10 @@ import org.eclipse.jface.internal.databinding.swt.ControlFontProperty;
 import org.eclipse.jface.internal.databinding.swt.ControlForegroundProperty;
 import org.eclipse.jface.internal.databinding.swt.ControlLocationProperty;
 import org.eclipse.jface.internal.databinding.swt.ControlSizeProperty;
-import org.eclipse.jface.internal.databinding.swt.ControlVisibleProperty;
 import org.eclipse.jface.internal.databinding.swt.DateTimeSelectionProperty;
 import org.eclipse.jface.internal.databinding.swt.ListSelectionProperty;
+import org.eclipse.jface.internal.databinding.swt.LocalDateSelectionProperty;
+import org.eclipse.jface.internal.databinding.swt.LocalTimeSelectionProperty;
 import org.eclipse.jface.internal.databinding.swt.MenuItemSelectionProperty;
 import org.eclipse.jface.internal.databinding.swt.ScaleSelectionProperty;
 import org.eclipse.jface.internal.databinding.swt.SliderSelectionProperty;
@@ -50,6 +53,7 @@ import org.eclipse.jface.internal.databinding.swt.WidgetSingleSelectionIndexProp
 import org.eclipse.jface.internal.databinding.swt.WidgetTextProperty;
 import org.eclipse.jface.internal.databinding.swt.WidgetTextWithEventsProperty;
 import org.eclipse.jface.internal.databinding.swt.WidgetTooltipTextProperty;
+import org.eclipse.jface.internal.databinding.swt.WidgetVisibleProperty;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.CCombo;
 import org.eclipse.swt.custom.CLabel;
@@ -80,6 +84,7 @@ import org.eclipse.swt.widgets.TabItem;
 import org.eclipse.swt.widgets.Table;
 import org.eclipse.swt.widgets.TableColumn;
 import org.eclipse.swt.widgets.Text;
+import org.eclipse.swt.widgets.ToolBar;
 import org.eclipse.swt.widgets.ToolItem;
 import org.eclipse.swt.widgets.ToolTip;
 import org.eclipse.swt.widgets.TrayItem;
@@ -264,6 +269,30 @@ public class WidgetProperties {
 		return new DateTimeSelectionProperty();
 	}
 
+	/**
+	 * Returns a value property for observing the selection state of a
+	 * {@link DateTime} with the {@link SWT#DATE} or {@link SWT#CALENDAR} style.
+	 *
+	 * @return a value property for observing the selection state of a
+	 *         {@link DateTime}.
+	 * @since 1.12
+	 */
+	public static IWidgetValueProperty<DateTime, LocalDate> localDateSelection() {
+		return new LocalDateSelectionProperty();
+	}
+
+	/**
+	 * Returns a value property for observing the selection state of a
+	 * {@link DateTime} with the {@link SWT#TIME} style.
+	 *
+	 * @return a value property for observing the selection state of a
+	 *         {@link DateTime}.
+	 * @since 1.12
+	 */
+	public static IWidgetValueProperty<DateTime, LocalTime> localTimeSelection() {
+		return new LocalTimeSelectionProperty();
+	}
+
 	/**
 	 * Returns a value property for observing the selection state of a
 	 * {@link Button}.
@@ -440,12 +469,16 @@ public class WidgetProperties {
 
 	/**
 	 * Returns a value property for observing the visibility state of a
-	 * {@link Control}.
+	 * {@link Control}, {@link Menu}, {@link ScrollBar}, {@link ToolBar} or
+	 * {@link ToolTip}.
+	 *
+	 * @see Control#getVisible
 	 *
 	 * @return a value property for observing the visibility state of a
-	 *         {@link Control}.
+	 *         {@link Control}, {@link Menu}, {@link ScrollBar}, {@link ToolBar} or
+	 *         {@link ToolTip}.
 	 */
-	public static <S extends Control> IWidgetValueProperty<S, Boolean> visible() {
-		return new ControlVisibleProperty<>();
+	public static <S extends Widget> IWidgetValueProperty<S, Boolean> visible() {
+		return new WidgetVisibleProperty<>();
 	}
 }
