@@ -22,12 +22,12 @@ import org.eclipse.swt.widgets.Spinner;
  */
 public class SpinnerMaximumProperty extends WidgetIntValueProperty<Spinner> {
 	@Override
-	int doGetIntValue(Spinner source) {
+	protected int doGetIntValue(Spinner source) {
 		return source.getMaximum();
 	}
 
 	@Override
-	void doSetIntValue(Spinner source, int value) {
+	protected void doSetIntValue(Spinner source, int value) {
 		source.setMaximum(value);
 	}
 
