@@ -197,6 +197,20 @@ public final class GridDataFactory {
 		return new GridDataFactory(data);
 	}
 
+	/**
+	 * Creates a new GridDataFactory initialized with given style. This factory will
+	 * generate GridData that is equivalent to "new GridData(style)".
+	 *
+	 * @param style the style to be applied. Refer to {@link GridData#GridData(int)}
+	 *              for possible values.
+	 *
+	 * @return a new GridDataFactory instance
+	 * @since 3.17
+	 */
+	public static GridDataFactory create(int style) {
+		return new GridDataFactory(new GridData(style));
+	}
+
 	/**
 	 * Returns a GridDataFactory initialized with heuristicly generated defaults for the given control.
 	 * To be precise, this method picks the default values that GridLayoutFactory.generateLayout
@@ -211,7 +225,7 @@ public final class GridDataFactory {
 	 * </p>
 	 *
 	 * @see GridLayoutFactory#generateLayout(org.eclipse.swt.widgets.Composite)
-	 * @param theControl
+	 * @param theControl the control to get factory with default values for
 	 * @return a GridDataFactory initialized with defaults that GridLayoutFactory would have assigned
 	 * @since 3.3
 	 */
@@ -229,7 +243,7 @@ public final class GridDataFactory {
 	 * </p>
 	 *
 	 * @see GridLayoutFactory#generateLayout(org.eclipse.swt.widgets.Composite)
-	 * @param theControl
+	 * @param theControl the control to change
 	 * @param hSpan number of columns spanned by the control
 	 * @param vSpan number of rows spanned by the control
 	 * @since 3.3
@@ -248,7 +262,7 @@ public final class GridDataFactory {
 	 * </p>
 	 *
 	 * @see GridLayoutFactory#generateLayout(org.eclipse.swt.widgets.Composite)
-	 * @param theControl
+	 * @param theControl the control to change
 	 * @param span The x coordinate indicates the number of
 	 * columns spanned, and the y coordinate indicates the number of rows.
 	 * @since 3.3
