@@ -945,17 +945,15 @@ public class TreeViewer extends AbstractTreeViewer {
 				TreeItem item = (TreeItem) widget;
 				if (!hasChildren) {
 					item.setItemCount(0);
-				} else {
-					if (!item.getExpanded()) {
-						item.setItemCount(1);
-						TreeItem child = item.getItem(0);
-						if (child.getData() != null) {
-							disassociate(child);
-						}
-						item.clear(0, true);
-					} else {
-						virtualLazyUpdateChildCount(item, item.getItemCount());
+				} else if (!item.getExpanded()) {
+					item.setItemCount(1);
+					TreeItem child = item.getItem(0);
+					if (child.getData() != null) {
+						disassociate(child);
 					}
+					item.clear(0, true);
+				} else {
+					virtualLazyUpdateChildCount(item, item.getItemCount());
 				}
 			}
 		});
