@@ -174,14 +174,12 @@ public class ContainerGenerator {
 					}
 					container = (IContainer) resource;
 					subMonitor.worked(1);
+				} else if (i == 0) {
+					IProject projectHandle = createProjectHandle(root, currentSegment);
+					container = createProject(projectHandle, subMonitor.split(1));
 				} else {
-					if (i == 0) {
-						IProject projectHandle = createProjectHandle(root, currentSegment);
-						container = createProject(projectHandle, subMonitor.split(1));
-					} else {
-						IFolder folderHandle = createFolderHandle(container, currentSegment);
-						container = createFolder(folderHandle, subMonitor.split(1));
-					}
+					IFolder folderHandle = createFolderHandle(container, currentSegment);
+					container = createFolder(folderHandle, subMonitor.split(1));
 				}
 			}
 		}, null, IResource.NONE, monitor);
