@@ -180,7 +180,7 @@ public class ImportTypeDialog extends TrayDialog {
 	}
 
 	/** Set the project that is the destination of the import operation
-	 * @param resource
+	 * @param resource the resource
 	 */
 	public void setResource(IResource resource) {
 		receivingResource = resource;
@@ -238,7 +238,7 @@ public class ImportTypeDialog extends TrayDialog {
 		if (!found) {
 			if (buffer.length() > 0)
 				buffer.append(":"); //$NON-NLS-1$
-			buffer.append(Integer.toString(operationMask) + "," + value); //$NON-NLS-1$
+			buffer.append(operationMask + "," + value); //$NON-NLS-1$
 		}
 		String newValue = buffer.toString();
 		IDEWorkbenchPlugin.getDefault().getPreferenceStore().setValue(key, newValue);
