@@ -137,8 +137,6 @@ public class IDEWorkbenchMessages extends NLS {
 	public static String Workbench_new;
 	public static String OpenWorkspaceAction_text;
 	public static String OpenWorkspaceAction_toolTip;
-	public static String OpenWorkspaceAction_errorTitle;
-	public static String OpenWorkspaceAction_errorMessage;
 	public static String OpenWorkspaceAction_other;
 	public static String NewProjectAction_text;
 	public static String NewProjectAction_toolTip;
@@ -536,6 +534,7 @@ public class IDEWorkbenchMessages extends NLS {
 	public static String UrlHandlerPreferencePage_Handler_Label;
 	public static String UrlHandlerPreferencePage_Handler_Text_No_Application;
 	public static String UrlHandlerPreferencePage_Page_Description;
+	public static String UrlHandlerPreferencePage_LoadingText;
 	public static String UrlHandlerPreferencePage_ColumnName_SchemeName;
 	public static String UrlHandlerPreferencePage_ColumnName_SchemeDescription;
 	public static String UrlHandlerPreferencePage_ColumnName_Handler;
@@ -625,6 +624,7 @@ public class IDEWorkbenchMessages extends NLS {
 	public static String FileHistory_entries;
 	public static String FileHistory_diskSpace;
 	public static String FileHistory_applyPolicy;
+	public static String FileHistory_keepDerivedState;
 	public static String FileHistory_mustBePositive;
 	public static String FileHistory_invalid;
 	public static String FileHistory_exceptionSaving;
@@ -1044,6 +1044,8 @@ public class IDEWorkbenchMessages extends NLS {
 	public static String IDEApplication_versionMessage_olderWorkspace;
 	public static String IDEApplication_version_doNotWarnAgain;
 	public static String IDEApplication_version_continue;
+	public static String IDEApplication_version_switch;
+	public static String IDEApplication_version_exit;
 	public static String GlobalBuildAction_BuildRunningTitle;
 	public static String GlobalBuildAction_BuildRunningMessage;
 	public static String CleanDialog_buildCleanAuto;
