@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2007, 2016 IBM Corporation and others.
+ * Copyright (c) 2007, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -16,6 +16,8 @@
 package org.eclipse.ui.internal.views.markers;
 
 import java.net.URL;
+import java.text.CollationKey;
+import java.text.Collator;
 
 import org.eclipse.core.resources.IMarker;
 import org.eclipse.core.resources.IResource;
@@ -32,7 +34,6 @@ import org.eclipse.swt.graphics.GC;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.widgets.Control;
 import org.eclipse.ui.IViewPart;
-import org.eclipse.ui.internal.ide.IDEInternalPreferences;
 import org.eclipse.ui.internal.ide.IDEInternalWorkbenchImages;
 import org.eclipse.ui.internal.ide.IDEWorkbenchPlugin;
 import org.eclipse.ui.internal.ide.Policy;
@@ -48,9 +49,6 @@ import org.eclipse.ui.views.markers.internal.MarkerGroup;
 import org.eclipse.ui.views.markers.internal.MarkerGroupingEntry;
 import org.eclipse.ui.views.markers.internal.MarkerMessages;
 
-import com.ibm.icu.text.CollationKey;
-import com.ibm.icu.text.Collator;
-
 /**
  * MarkerSupportUtilities is the class that maintains constants and
  * functionality used by multiple classes.
@@ -88,7 +86,6 @@ public class MarkerSupportInternalUtilities {
 	static final CollationKey EMPTY_COLLATION_KEY = Collator.getInstance()
 			.getCollationKey(MarkerSupportInternalUtilities.EMPTY_STRING);
 
-	static final IMarker[] EMPTY_MARKER_ARRAY = new IMarker[0];
 	static final MarkerSupportItem[] EMPTY_MARKER_ITEM_ARRAY = new MarkerSupportItem[0];
 	static final IResource[] EMPTY_RESOURCE_ARRAY = new IResource[0];
 
@@ -113,29 +110,6 @@ public class MarkerSupportInternalUtilities {
 	 */
 	public static final String IMG_MARKERS_QUICK_FIX_DECORATION_PATH = "markers/contassist_ovr.png"; //$NON-NLS-1$
 
-	/**
-	 * A constant to map migration to the filter being migrated
-	 */
-	public static final String MIGRATE_PREFERENCE_CONSTANT = "_MIGRATE"; //$NON-NLS-1$
-
-	/**
-	 * Constant for the bookmark filters migration.
-	 */
-	public static final String MIGRATE_BOOKMARK_FILTERS = IDEInternalPreferences.BOOKMARKS_FILTERS
-			+ MIGRATE_PREFERENCE_CONSTANT;
-
-	/**
-	 * Constant for the problem filters migration.
-	 */
-	public static final String MIGRATE_PROBLEM_FILTERS = IDEInternalPreferences.PROBLEMS_FILTERS
-			+ MIGRATE_PREFERENCE_CONSTANT;
-
-	/**
-	 * Constant for the task filters migration.
-	 */
-	public static final String MIGRATE_TASK_FILTERS = IDEInternalPreferences.TASKS_FILTERS
-			+ MIGRATE_PREFERENCE_CONSTANT;
-
 	/**
 	 * The string value of the false value for a boolean attribute.
 	 */
@@ -243,7 +217,7 @@ public class MarkerSupportInternalUtilities {
 	 */
 	public static final int getFontWidth(Control control) {
 		GC gc = new GC(control.getDisplay());
-		int width = gc.getFontMetrics().getAverageCharWidth();
+		int width = (int) gc.getFontMetrics().getAverageCharacterWidth();
 		gc.dispose();
 		return width;
 	}
