@@ -748,8 +748,7 @@ abstract class ViewerColumnsDialog<T> extends ViewerSettingsAndStatusDialog {
 			final int prime = 31;
 			int result = 1;
 			result = prime * result + Objects.hashCode(key);
-			result = prime * result + keyIndex;
-			return result;
+			return prime * result + keyIndex;
 		}
 
 		@Override
@@ -770,7 +769,7 @@ abstract class ViewerColumnsDialog<T> extends ViewerSettingsAndStatusDialog {
 		}
 
 		private static ViewerColumnsDialog<TestData> getColumnsDialog(Shell shell, final TestData[] colums) {
-			ViewerColumnsDialog<TestData> dialog = new ViewerColumnsDialog<TestData>(shell) {
+			ViewerColumnsDialog<TestData> dialog = new ViewerColumnsDialog<>(shell) {
 
 				@Override
 				protected IColumnInfoProvider<TestData> getColumnInfoProvider() {
@@ -792,7 +791,7 @@ abstract class ViewerColumnsDialog<T> extends ViewerSettingsAndStatusDialog {
 		}
 
 		private static IColumnUpdater<TestData> getUpdater() {
-			return new IColumnUpdater<TestData>() {
+			return new IColumnUpdater<>() {
 
 				@Override
 				public void setColumnWidth(TestData columnObj, int newWidth) {
@@ -824,7 +823,7 @@ abstract class ViewerColumnsDialog<T> extends ViewerSettingsAndStatusDialog {
 		}
 
 		private static IColumnInfoProvider<TestData> getInfoProvider() {
-			return new IColumnInfoProvider<TestData>() {
+			return new IColumnInfoProvider<>() {
 
 				@Override
 				public boolean isColumnVisible(TestData columnObj) {
