@@ -80,15 +80,22 @@ import org.eclipse.ui.part.ShowInContext;
 import org.eclipse.ui.part.ViewPart;
 import org.eclipse.ui.plugin.AbstractUIPlugin;
 import org.eclipse.ui.views.navigator.ShowInNavigatorAction;
+import org.osgi.framework.FrameworkUtil;
 
 /**
- * Main class for the bookmark navigator for displaying bookmarks on
- * resources and opening an editor on the bookmarked resource when the user
- * commands.
+ * Main class for the bookmark navigator for displaying bookmarks on resources
+ * and opening an editor on the bookmarked resource when the user commands.
  * <p>
- * @deprecated This view is no longer in use as of Eclipse 3.4.
- * The view referenced by {@link IPageLayout#ID_BOOKMARKS} is an {@link ExtendedMarkersView}.
- * </p>
+ *
+ * @deprecated This view is no longer in use as of Eclipse 3.4. The view
+ *             referenced by {@link IPageLayout#ID_BOOKMARKS} is an
+ *             {@link ExtendedMarkersView}.
+ *             </p>
+ *
+ *
+ * Marked for deletion, see Bug 550439
+ *
+ * @noreference
  * @noinstantiate This class is not intended to be instantiated by clients.
  * @noextend This class is not intended to be subclassed by clients.
  */
@@ -173,7 +180,8 @@ public class BookmarkNavigator extends ViewPart {
 			comparator.setTopPriority(column);
 			updateSortState();
 			viewer.refresh();
-			IDialogSettings workbenchSettings = getPlugin().getDialogSettings();
+			IDialogSettings workbenchSettings = PlatformUI
+					.getDialogSettingsProvider(FrameworkUtil.getBundle(BookmarkNavigator.class)).getDialogSettings();
 			IDialogSettings settings = workbenchSettings
 					.getSection("BookmarkSortState");//$NON-NLS-1$
 			if (settings == null) {
@@ -199,7 +207,8 @@ public class BookmarkNavigator extends ViewPart {
 			comparator.setTopPriorityDirection(direction);
 			updateSortState();
 			viewer.refresh();
-			IDialogSettings workbenchSettings = getPlugin().getDialogSettings();
+			IDialogSettings workbenchSettings = PlatformUI
+					.getDialogSettingsProvider(FrameworkUtil.getBundle(BookmarkNavigator.class)).getDialogSettings();
 			IDialogSettings settings = workbenchSettings
 					.getSection("BookmarkSortState");//$NON-NLS-1$
 			if (settings == null) {
@@ -255,7 +264,7 @@ public class BookmarkNavigator extends ViewPart {
 		// support action contributions.
 		MenuManager mgr = new MenuManager();
 		mgr.setRemoveAllWhenShown(true);
-		mgr.addMenuListener(mgr1 -> fillContextMenu(mgr1));
+		mgr.addMenuListener(this::fillContextMenu);
 		Menu menu = mgr.createContextMenu(viewer.getControl());
 		viewer.getControl().setMenu(menu);
 		getSite().registerContextMenu(mgr, viewer);
@@ -301,7 +310,8 @@ public class BookmarkNavigator extends ViewPart {
 		viewer.setInput(ResourcesPlugin.getWorkspace().getRoot());
 		viewer.setComparator(comparator);
 
-		IDialogSettings workbenchSettings = getPlugin().getDialogSettings();
+		IDialogSettings workbenchSettings = PlatformUI
+				.getDialogSettingsProvider(FrameworkUtil.getBundle(BookmarkNavigator.class)).getDialogSettings();
 		IDialogSettings settings = workbenchSettings
 				.getSection("BookmarkSortState");//$NON-NLS-1$
 		comparator.restoreState(settings);
@@ -356,7 +366,7 @@ public class BookmarkNavigator extends ViewPart {
 			return adapterClass.cast((IShowInSource) () -> new ShowInContext(null, getViewer().getSelection()));
 		}
 		if (adapterClass == IShowInTargetList.class) {
-			return adapterClass.cast((IShowInTargetList) () -> new String[] { IPageLayout.ID_RES_NAV });
+			return adapterClass.cast((IShowInTargetList) () -> new String[] { IPageLayout.ID_PROJECT_EXPLORER });
 		}
 		return super.getAdapter(adapterClass);
 	}
@@ -459,7 +469,7 @@ public class BookmarkNavigator extends ViewPart {
 						.getLabelProvider();
 				for (int i = 0; i < markers.length; i++) {
 					if (i > 0) {
-						buffer.append(System.getProperty("line.separator")); //$NON-NLS-1$
+						buffer.append(System.lineSeparator());
 					}
 					String text = provider.getText(markers[i]);
 					if(text != null) {
@@ -476,7 +486,7 @@ public class BookmarkNavigator extends ViewPart {
 		IWorkspaceRoot root = ResourcesPlugin.getWorkspace().getRoot();
 		IMemento selectionMem = memento.getChild(TAG_SELECTION);
 		if (selectionMem != null) {
-			ArrayList selectionList = new ArrayList();
+			ArrayList<IMarker> selectionList = new ArrayList<>();
 			for (IMemento markerMem : selectionMem.getChildren(TAG_MARKER)) {
 				try {
 					long id = Long.parseLong(markerMem.getString(TAG_ID));
@@ -582,7 +592,8 @@ public class BookmarkNavigator extends ViewPart {
 				}
 				updateSortState();
 				viewer.refresh();
-				IDialogSettings workbenchSettings = getPlugin()
+				IDialogSettings workbenchSettings = PlatformUI
+						.getDialogSettingsProvider(FrameworkUtil.getBundle(BookmarkNavigator.class))
 						.getDialogSettings();
 				IDialogSettings settings = workbenchSettings
 						.getSection("BookmarkSortState");//$NON-NLS-1$
