@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2015 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,15 +10,17 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Alexander Fedorov <alexander.fedorov@arsysop.ru> - ongoing support
  *******************************************************************************/
 package org.eclipse.ui.views.markers.internal;
 
+import java.text.CollationKey;
+import java.text.Collator;
+
 import org.eclipse.core.resources.IMarker;
 import org.eclipse.core.resources.IResource;
 import org.eclipse.core.runtime.CoreException;
-
-import com.ibm.icu.text.CollationKey;
-import com.ibm.icu.text.Collator;
+import org.eclipse.e4.ui.internal.workspace.markers.Translation;
 
 /**
  * This is a concrete class that stores the same type of information as the IMarkers
@@ -29,6 +31,8 @@ import com.ibm.icu.text.Collator;
  */
 public class ConcreteMarker extends MarkerNode{
 
+	private final Translation translation = new Translation();
+
 	private String description;
 
 	private String resourceName;
@@ -81,8 +85,8 @@ public class ConcreteMarker extends MarkerNode{
 	public void refresh() {
 		clearCache();
 
-		description = Util.getProperty(IMarker.MESSAGE, marker);
-		resourceName = Util.getResourceName(marker);
+		description = translation.message(marker).orElse(""); //$NON-NLS-1$
+		resourceName = translation.name(marker).orElse(""); //$NON-NLS-1$
 		inFolder = Util.getContainerName(marker);
 		shortFolder = null;
 		line = marker.getAttribute(IMarker.LINE_NUMBER, -1);
