@@ -18,9 +18,11 @@ import org.eclipse.jface.viewers.IStructuredSelection;
 import org.eclipse.jface.wizard.Wizard;
 import org.eclipse.ui.IImportWizard;
 import org.eclipse.ui.IWorkbench;
+import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.internal.ide.IDEWorkbenchPlugin;
 import org.eclipse.ui.internal.wizards.datatransfer.DataTransferMessages;
 import org.eclipse.ui.internal.wizards.datatransfer.WizardProjectsImportPage;
+import org.osgi.framework.FrameworkUtil;
 
 /**
  * Standard workbench wizard for importing projects defined outside of the
@@ -32,7 +34,7 @@ import org.eclipse.ui.internal.wizards.datatransfer.WizardProjectsImportPage;
  * <p>
  * Example:
  * </p>
- * 
+ *
  * <pre>
  * IWizard wizard = new ExternalProjectImportWizard();
  * wizard.init(workbench, selection);
@@ -44,7 +46,7 @@ import org.eclipse.ui.internal.wizards.datatransfer.WizardProjectsImportPage;
  * user. When the user hits Finish, a project is created with the location
  * specified by the user.
  * </p>
- * 
+ *
  * @noextend This class is not intended to be subclassed by clients.
  */
 
@@ -73,7 +75,8 @@ public class ExternalProjectImportWizard extends Wizard implements
 		super();
 		this.initialPath = initialPath;
 		setNeedsProgressMonitor(true);
-		IDialogSettings workbenchSettings = IDEWorkbenchPlugin.getDefault()
+		IDialogSettings workbenchSettings = PlatformUI
+				.getDialogSettingsProvider(FrameworkUtil.getBundle(ExternalProjectImportWizard.class))
 				.getDialogSettings();
 
 		IDialogSettings wizardSettings = workbenchSettings
