@@ -128,35 +128,34 @@ public class ResourceDropAdapterAssistant extends CommonDropAdapterAssistant {
 			for (IResource res : selectedResources) {
 				if(res instanceof IProject) {
 					bProjectDrop = true;
+					break;
 				}
 			}
 			if(bProjectDrop) {
 				// drop of projects not supported on other IResources
 				// "Path for project must have only one segment."
 				message = WorkbenchNavigatorMessages.DropAdapter_canNotDropProjectIntoProject;
+			} else if (selectedResources.length == 0) {
+				message = WorkbenchNavigatorMessages.DropAdapter_dropOperationErrorOther;
 			} else {
-				if (selectedResources.length == 0) {
-					message = WorkbenchNavigatorMessages.DropAdapter_dropOperationErrorOther;
-				} else {
-					CopyFilesAndFoldersOperation operation;
-					if (aDropOperation == DND.DROP_COPY) {
-						if (Policy.DEBUG_DND) {
-							System.out
-									.println("ResourceDropAdapterAssistant.validateDrop validating COPY."); //$NON-NLS-1$
-						}
+				CopyFilesAndFoldersOperation operation;
+				if (aDropOperation == DND.DROP_COPY) {
+					if (Policy.DEBUG_DND) {
+						System.out
+								.println("ResourceDropAdapterAssistant.validateDrop validating COPY."); //$NON-NLS-1$
+					}
 
-						operation = new CopyFilesAndFoldersOperation(getShell());
-					} else {
-						if (Policy.DEBUG_DND) {
-							System.out
-									.println("ResourceDropAdapterAssistant.validateDrop validating MOVE."); //$NON-NLS-1$
-						}
-						operation = new MoveFilesAndFoldersOperation(getShell());
-					}
-					if (operation.validateDestination(destination, selectedResources) != null) {
-						operation.setVirtualFolders(true);
-						message = operation.validateDestination(destination, selectedResources);
+					operation = new CopyFilesAndFoldersOperation(getShell());
+				} else {
+					if (Policy.DEBUG_DND) {
+						System.out
+								.println("ResourceDropAdapterAssistant.validateDrop validating MOVE."); //$NON-NLS-1$
 					}
+					operation = new MoveFilesAndFoldersOperation(getShell());
+				}
+				if (operation.validateDestination(destination, selectedResources) != null) {
+					operation.setVirtualFolders(true);
+					message = operation.validateDestination(destination, selectedResources);
 				}
 			}
 		} // file import?
@@ -468,9 +467,6 @@ public class ResourceDropAdapterAssistant extends CommonDropAdapterAssistant {
 					}
 				};
 
-				if (returnStatus != null)
-					return returnStatus;
-
 				try {
 					PlatformUI.getWorkbench().getProgressService().run(false, false, checkOp);
 				} catch (InterruptedException e) {
@@ -479,6 +475,10 @@ public class ResourceDropAdapterAssistant extends CommonDropAdapterAssistant {
 					return WorkbenchNavigatorPlugin.createErrorStatus(0, e.getLocalizedMessage(), e);
 				}
 
+				if (returnStatus != null) {
+					return returnStatus;
+				}
+
 				if (refactoringStatus.hasEntries()) {
 					Dialog dialog= RefactoringUI.createLightWeightStatusDialog(refactoringStatus, getShell(), WorkbenchNavigatorMessages.MoveResourceAction_title);
 					int result = dialog.open();
@@ -501,9 +501,6 @@ public class ResourceDropAdapterAssistant extends CommonDropAdapterAssistant {
 					}
 				};
 
-				if (returnStatus != null)
-					return returnStatus;
-
 				try {
 					PlatformUI.getWorkbench().getProgressService().run(false, false, refactorOp);
 				} catch (InterruptedException e) {
@@ -512,6 +509,9 @@ public class ResourceDropAdapterAssistant extends CommonDropAdapterAssistant {
 					return WorkbenchNavigatorPlugin.createErrorStatus(0, e.getLocalizedMessage(), e);
 				}
 
+				if (returnStatus != null) {
+					return returnStatus;
+				}
 			} catch (CoreException ex) {
 				return WorkbenchNavigatorPlugin.createErrorStatus(0, ex.getLocalizedMessage(), ex);
 			} catch (OperationCanceledException e) {
