@@ -147,6 +147,7 @@ public class CommonFilterSelectionDialog extends TrayDialog {
 
 		if (commonFiltersTab != null) {
 			commonFiltersTab.addSelectionChangedListener(getSelectionListener());
+			commonFiltersTab.setInitialFocus();
 		}
 
 		if (contentExtensionsTab != null) {
@@ -154,8 +155,11 @@ public class CommonFilterSelectionDialog extends TrayDialog {
 					.addSelectionChangedListener(getSelectionListener());
 		}
 
-		commonFiltersTab.setInitialFocus();
 
+		if (customizationsTabFolder.getTabList().length > 0) {
+			customizationsTabFolder.setSelection(0);
+
+		}
 		return customizationsTabFolder;
 	}
 
@@ -227,7 +231,7 @@ public class CommonFilterSelectionDialog extends TrayDialog {
 	protected void okPressed() {
 
 		if (contentExtensionsTab != null) {
-			List<String> checkedExtensions = new ArrayList<String>();
+			List<String> checkedExtensions = new ArrayList<>();
 			TableItem[] tableItems = contentExtensionsTab.getTable().getItems();
 			INavigatorContentDescriptor descriptor;
 			for (TableItem tableItem : tableItems) {
