@@ -16,9 +16,8 @@
  *******************************************************************************/
 package org.eclipse.ui.internal.views.log;
 
-import com.ibm.icu.text.DateFormat;
 import java.io.*;
-import java.text.Collator;
+import java.text.*;
 import java.util.*;
 import java.util.List;
 import org.eclipse.core.runtime.IAdaptable;
@@ -38,6 +37,7 @@ import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.*;
 import org.eclipse.ui.*;
+import org.osgi.framework.FrameworkUtil;
 
 /**
  * Displays details about Log Entry. Event information is split in three
@@ -92,7 +92,8 @@ public class EventDetailsDialog extends TrayDialog {
 	private Point dialogSize;
 	private int[] sashWeights;
 
-	private DateFormat dateFormat = DateFormat.getDateTimeInstance(DateFormat.SHORT, DateFormat.SHORT);
+	private DateFormat dateFormat = DateFormat.getDateInstance(DateFormat.SHORT);
+	private DateFormat timeFormat = new SimpleDateFormat("HH:mm:ss.SSS"); //$NON-NLS-1$
 
 	/**
 	 *
@@ -219,6 +220,7 @@ public class EventDetailsDialog extends TrayDialog {
 
 		applyDialogFont(buttonBar);
 		getButton(IDialogConstants.OK_ID).setFocus();
+		getButton(IDialogConstants.OK_ID).setText(IDialogConstants.CLOSE_LABEL);
 	}
 
 	@Override
@@ -243,16 +245,14 @@ public class EventDetailsDialog extends TrayDialog {
 			}
 			childIndex--;
 			entry = entryChildren[childIndex];
-		} else {
-			if (parentEntry instanceof LogEntry) {
-				entry = parentEntry;
-				if (isChild(entry)) {
-					setEntryChildren((AbstractEntry) entry.getParent(entry));
-				} else {
-					setEntryChildren();
-				}
-				resetChildIndex();
+		} else if (parentEntry instanceof LogEntry) {
+			entry = parentEntry;
+			if (isChild(entry)) {
+				setEntryChildren((AbstractEntry) entry.getParent(entry));
+			} else {
+				setEntryChildren();
 			}
+			resetChildIndex();
 		}
 		setEntrySelectionInTable();
 	}
@@ -355,7 +355,9 @@ public class EventDetailsDialog extends TrayDialog {
 		if (entry instanceof LogEntry) {
 			LogEntry logEntry = (LogEntry) entry;
 
-			String strDate = dateFormat.format(logEntry.getDate());
+			String strDate = MessageFormat.format("{0}, {1}", //$NON-NLS-1$
+					dateFormat.format(logEntry.getDate()), //
+					timeFormat.format(logEntry.getDate()));
 			dateLabel.setText(strDate);
 			plugInIdLabel.setText(logEntry.getPluginId());
 			severityImageLabel.setImage(labelProvider.getColumnImage(entry, 0));
@@ -738,7 +740,7 @@ public class EventDetailsDialog extends TrayDialog {
 
 	/**
 	 * Loads filters from preferences.
-	 * 
+	 *
 	 * @return filters from preferences or empty array
 	 *
 	 * @since 3.4
@@ -767,7 +769,7 @@ public class EventDetailsDialog extends TrayDialog {
 	 * Filters stack trace. Every stack trace line is compared against all patterns.
 	 * If line contains any of pattern strings, it's excluded from output.
 	 *
-	 * @returns filtered stack trace
+	 * @return filtered stack trace
 	 * @since 3.4
 	 */
 	private String filterStack(String stack) {
@@ -799,7 +801,7 @@ public class EventDetailsDialog extends TrayDialog {
 
 	/**
 	 * Stores the current state in the dialog settings.
-	 * 
+	 *
 	 * @since 2.0
 	 */
 	private void storeSettings() {
@@ -813,7 +815,8 @@ public class EventDetailsDialog extends TrayDialog {
 	 * @return the dialog settings to be used
 	 */
 	private IDialogSettings getDialogSettings() {
-		IDialogSettings settings = Activator.getDefault().getDialogSettings();
+		IDialogSettings settings = PlatformUI
+				.getDialogSettingsProvider(FrameworkUtil.getBundle(EventDetailsDialog.class)).getDialogSettings();
 		IDialogSettings dialogSettings = settings.getSection(getClass().getName());
 		if (dialogSettings == null)
 			dialogSettings = settings.addNewSection(getClass().getName());
@@ -864,7 +867,7 @@ public class EventDetailsDialog extends TrayDialog {
 
 	/**
 	 * Utility method to get all top level elements of the Log View
-	 * 
+	 *
 	 * @return top level elements of the Log View
 	 */
 	private AbstractEntry[] getElements() {
