@@ -97,15 +97,15 @@ public class TabbedPropertySheetPage
 
 	private TabContents currentTab;
 
-	private Map descriptorToTab;
+	private Map<ITabDescriptor, TabContents> descriptorToTab;
 
-	private Map tabToComposite;
+	private Map<TabContents, Composite> tabToComposite;
 
-	private List selectionQueue;
+	private List<String> selectionQueue;
 
 	private boolean selectionQueueLocked;
 
-	private List tabSelectionListeners;
+	private List<ITabSelectionListener> tabSelectionListeners;
 
 	private IWorkbenchWindow cachedWorkbenchWindow;
 
@@ -203,13 +203,13 @@ public class TabbedPropertySheetPage
 				// create tab if necessary
 				// can not cache based on the id - tabs may have the same id,
 				// but different section depending on the selection
-				tab = (TabContents) descriptorToTab.get(descriptor);
+				tab = descriptorToTab.get(descriptor);
 
 				if (tab != currentTab) {
 					hideTab(currentTab);
 				}
 
-				Composite tabComposite = (Composite) tabToComposite.get(tab);
+				Composite tabComposite = tabToComposite.get(tab);
 				if (tabComposite == null) {
 					tabComposite = createTabComposite();
 					tab.createControls(tabComposite,
@@ -244,7 +244,7 @@ public class TabbedPropertySheetPage
 		 */
 		private void showTab(TabContents target) {
 			if (target != null) {
-				Composite tabComposite = (Composite) tabToComposite.get(target);
+				Composite tabComposite = tabToComposite.get(target);
 				if (tabComposite != null) {
 					/**
 					 * the following method call order is important - do not
@@ -262,7 +262,7 @@ public class TabbedPropertySheetPage
 		 */
 		private void hideTab(TabContents target) {
 			if (target != null) {
-				Composite tabComposite = (Composite) tabToComposite.get(target);
+				Composite tabComposite = tabToComposite.get(target);
 				if (tabComposite != null) {
 					target.aboutToBeHidden();
 					tabComposite.setVisible(false);
@@ -298,9 +298,9 @@ public class TabbedPropertySheetPage
 			boolean showTitleBar) {
 		hasTitleBar = showTitleBar;
 		contributor = tabbedPropertySheetPageContributor;
-		tabToComposite = new HashMap();
-		selectionQueue = new ArrayList(10);
-		tabSelectionListeners = new ArrayList();
+		tabToComposite = new HashMap<>();
+		selectionQueue = new ArrayList<>(10);
+		tabSelectionListeners = new ArrayList<>();
 		initContributor(contributor.getContributorId());
 	}
 
@@ -407,7 +407,7 @@ public class TabbedPropertySheetPage
 	 *            the contributor id.
 	 */
 	private void initContributor(String contributorId) {
-		descriptorToTab = new HashMap();
+		descriptorToTab = new HashMap<>();
 		if (contributor.getContributorId().equals(contributorId)) {
 			/**
 			 * default contributor from the workbench part.
@@ -466,7 +466,7 @@ public class TabbedPropertySheetPage
 		}
 
 		disposeTabs(descriptorToTab.values());
-		descriptorToTab = new HashMap();
+		descriptorToTab = new HashMap<>();
 
 		/**
 		 * Remove the label provider change listener.
@@ -485,9 +485,6 @@ public class TabbedPropertySheetPage
 		}
 	}
 
-	/**
-	 * @see org.eclipse.ui.part.IPage#dispose()
-	 */
 	@Override
 	public void dispose() {
 
@@ -516,17 +513,11 @@ public class TabbedPropertySheetPage
 		currentSelection = null;
 	}
 
-	/**
-	 * @see org.eclipse.ui.part.IPage#getControl()
-	 */
 	@Override
 	public Control getControl() {
 		return tabbedPropertyComposite;
 	}
 
-	/**
-	 * @see org.eclipse.ui.part.IPage#setActionBars(org.eclipse.ui.IActionBars)
-	 */
 	@Override
 	public void setActionBars(IActionBars actionBars) {
 		// Override the undo and redo global action handlers
@@ -554,18 +545,11 @@ public class TabbedPropertySheetPage
 		}
 	}
 
-	/**
-	 * @see org.eclipse.ui.part.IPage#setFocus()
-	 */
 	@Override
 	public void setFocus() {
 		getControl().setFocus();
 	}
 
-	/**
-	 * @see org.eclipse.ui.ISelectionListener#selectionChanged(org.eclipse.ui.IWorkbenchPart,
-	 *      org.eclipse.jface.viewers.ISelection)
-	 */
 	@Override
 	public void selectionChanged(IWorkbenchPart part, ISelection selection) {
 		setInput(part, selection);
@@ -594,8 +578,7 @@ public class TabbedPropertySheetPage
 	public void resizeScrolledComposite() {
 		Point currentTabSize = new Point(0, 0);
 		if (currentTab != null) {
-			Composite sizeReference = (Composite) tabToComposite
-				.get(currentTab);
+			Composite sizeReference = tabToComposite.get(currentTab);
 			if (sizeReference != null) {
 				currentTabSize = sizeReference.computeSize(SWT.DEFAULT, SWT.DEFAULT);
 			}
@@ -630,13 +613,13 @@ public class TabbedPropertySheetPage
 	 * entries corresponding to the disposed TabContents objects are also
 	 * removed.
 	 *
-	 * @param tabs
+	 * @param tabs tabs to dispose
 	 * @since 3.6
 	 */
 	protected void disposeTabs(Collection tabs) {
-		for (Iterator iter = tabs.iterator(); iter.hasNext();) {
-			TabContents tab = (TabContents) iter.next();
-			Composite composite = (Composite) tabToComposite.remove(tab);
+		for (Iterator<TabContents> iter = tabs.iterator(); iter.hasNext();) {
+			TabContents tab = iter.next();
+			Composite composite = tabToComposite.remove(tab);
 			tab.dispose();
 			if (composite != null) {
 				composite.dispose();
@@ -650,8 +633,7 @@ public class TabbedPropertySheetPage
 	private int getLastTabSelection(IWorkbenchPart part, ISelection input) {
 		ITabDescriptor[] descriptors = registry.getTabDescriptors(part, input);
 		if (descriptors.length != 0) {
-			for (Iterator iter = selectionQueue.iterator(); iter.hasNext();) {
-				String text = (String) iter.next();
+			for (String text : selectionQueue) {
 				for (int i = 0; i < descriptors.length; i++) {
 					if (text.equals(descriptors[i].getLabel())) {
 						return i;
@@ -670,11 +652,10 @@ public class TabbedPropertySheetPage
 	 * @since 3.4
 	 */
 	protected void updateTabs(ITabDescriptor[] descriptors) {
-		Map newTabs = new HashMap(descriptors.length * 2);
+		Map<ITabDescriptor, TabContents> newTabs = new HashMap<>(descriptors.length * 2);
 		boolean disposingCurrentTab = (currentTab != null);
 		for (ITabDescriptor descriptor : descriptors) {
-			TabContents tab = (TabContents) descriptorToTab
-					.remove(descriptor);
+			TabContents tab = descriptorToTab.remove(descriptor);
 
 			if (tab != null && tab.controlsHaveBeenCreated()) {
 				if (tab == currentTab) {
@@ -799,8 +780,7 @@ public class TabbedPropertySheetPage
 			 */
 			return;
 		}
-		for (Iterator i = tabSelectionListeners.iterator(); i.hasNext();) {
-			ITabSelectionListener listener = (ITabSelectionListener) i.next();
+		for (ITabSelectionListener listener : tabSelectionListeners) {
 			listener.tabSelected(tabDescriptor);
 		}
 	}
@@ -869,9 +849,6 @@ public class TabbedPropertySheetPage
 		}
 	}
 
-	/**
-	 * @see org.eclipse.jface.viewers.ILabelProviderListener#labelProviderChanged(org.eclipse.jface.viewers.LabelProviderChangedEvent)
-	 */
 	@Override
 	public void labelProviderChanged(LabelProviderChangedEvent event) {
 		refreshTitleBar();
@@ -939,7 +916,7 @@ public class TabbedPropertySheetPage
 		 * new id. If all contributor id do not match, then fall back to default
 		 * contributor from the workbench part.
 		 */
-		Iterator i = structuredSelection.iterator();
+		Iterator<?> i = structuredSelection.iterator();
 		i.next();
 		while (i.hasNext()) {
 			newContributor = getTabbedPropertySheetPageContributor(i.next());
@@ -1002,11 +979,10 @@ public class TabbedPropertySheetPage
 	 * @since 3.5
 	 */
 	public ITabDescriptor[] getActiveTabs() {
-		List elements = tabbedPropertyViewer.getElements();
+		@SuppressWarnings("unchecked")
+		List<ITabDescriptor> elements = tabbedPropertyViewer.getElements();
 		if (elements != null && elements.size() > 0) {
-			ITabDescriptor[] tabDescriptors = (ITabDescriptor[]) elements
-					.toArray(new ITabDescriptor[0]);
-			return tabDescriptors;
+			return elements.toArray(new ITabDescriptor[elements.size()]);
 		}
 		return new ITabDescriptor[] {};
 	}
@@ -1019,10 +995,10 @@ public class TabbedPropertySheetPage
 	 * @since 3.5
 	 */
 	public void setSelectedTab(String id) {
-		List elements = tabbedPropertyViewer.getElements();
+		@SuppressWarnings("unchecked")
+		List<ITabDescriptor> elements = tabbedPropertyViewer.getElements();
 		if (elements != null && elements.size() > 0) {
-			for (Iterator i = elements.iterator(); i.hasNext();) {
-				ITabDescriptor tabDescriptor = (ITabDescriptor) i.next();
+			for (ITabDescriptor tabDescriptor : elements) {
 				if (tabDescriptor.getId() != null &&
 						tabDescriptor.getId().equals(id)) {
 					tabbedPropertyViewer.setSelection(new StructuredSelection(
@@ -1075,7 +1051,7 @@ public class TabbedPropertySheetPage
 	protected TabContents getTabContents(ITabDescriptor tabDescriptor) {
 		TabContents tabContents = null;
 		if (this.descriptorToTab.containsKey(tabDescriptor)) {
-			tabContents = (TabContents) this.descriptorToTab.get(tabDescriptor);
+			tabContents = this.descriptorToTab.get(tabDescriptor);
 		}
 		return tabContents;
 	}
