@@ -19,7 +19,6 @@ import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.Set;
 import org.eclipse.ui.IPluginContribution;
 import org.eclipse.ui.PlatformUI;
@@ -53,22 +52,20 @@ public final class WorkbenchActivityHelper {
 	 */
 	public static IIdentifier getIdentifier(IPluginContribution contribution) {
 		IWorkbenchActivitySupport workbenchActivitySupport = PlatformUI.getWorkbench().getActivitySupport();
-		IIdentifier identifier = workbenchActivitySupport.getActivityManager()
+		return workbenchActivitySupport.getActivityManager()
 				.getIdentifier(createUnifiedId(contribution));
-		return identifier;
 	}
 
 	/**
 	 * Answers whether a given contribution is allowed to be used based on activity
 	 * enablement. If it is currently disabled, then a dialog is opened and the user
-	 * is prompted to activate the requried activities. If the user declines their
+	 * is prompted to activate the required activities. If the user declines their
 	 * activation then false is returned. In all other cases <code>true</code> is
 	 * returned.
 	 *
 	 * @param object the contribution to test.
 	 * @return whether the contribution is allowed to be used based on activity
 	 *         enablement.
-	 * @deprecated
 	 * @see #allowUseOf(ITriggerPoint, Object)
 	 */
 	@Deprecated
@@ -162,7 +159,7 @@ public final class WorkbenchActivityHelper {
 	 * <pre>
 	 * pluginId / extensionId
 	 * </pre>
-	 * 
+	 *
 	 * . If the IPluginContribution does not define a plugin id then the extension
 	 * id alone is returned.
 	 *
@@ -541,8 +538,7 @@ public final class WorkbenchActivityHelper {
 	 * @since 3.4
 	 */
 	public static <T> Collection<T> restrictCollection(Collection<T> toBeFiltered, Collection<T> result) {
-		for (Iterator<T> iterator = toBeFiltered.iterator(); iterator.hasNext();) {
-			T item = iterator.next();
+		for (T item : toBeFiltered) {
 			if (!restrictUseOf(item)) {
 				result.add(item);
 			}
@@ -562,9 +558,9 @@ public final class WorkbenchActivityHelper {
 	 */
 	public static Object[] restrictArray(Object[] array) {
 		ArrayList<Object> list = new ArrayList<>(array.length);
-		for (int i = 0; i < array.length; i++) {
-			if (!restrictUseOf(array[i])) {
-				list.add(array[i]);
+		for (Object e : array) {
+			if (!restrictUseOf(e)) {
+				list.add(e);
 			}
 		}
 		return list.toArray((Object[]) Array.newInstance(array.getClass().getComponentType(), list.size()));
@@ -582,8 +578,7 @@ public final class WorkbenchActivityHelper {
 	 * @since 3.4
 	 */
 	public static <T> Collection<T> filterCollection(Collection<T> toBeFiltered, Collection<T> result) {
-		for (Iterator<T> iterator = toBeFiltered.iterator(); iterator.hasNext();) {
-			T item = iterator.next();
+		for (T item : toBeFiltered) {
 			if (!filterItem(item)) {
 				result.add(item);
 			}
@@ -603,9 +598,9 @@ public final class WorkbenchActivityHelper {
 	 */
 	public static Object[] filterArray(Object[] array) {
 		ArrayList<Object> list = new ArrayList<>(array.length);
-		for (int i = 0; i < array.length; i++) {
-			if (!filterItem(array[i])) {
-				list.add(array[i]);
+		for (Object e : array) {
+			if (!filterItem(e)) {
+				list.add(e);
 			}
 		}
 		return list.toArray((Object[]) Array.newInstance(array.getClass().getComponentType(), list.size()));
