@@ -71,6 +71,7 @@ import org.eclipse.ui.IWorkbenchPage;
 import org.eclipse.ui.IWorkbenchPart;
 import org.eclipse.ui.IWorkbenchPartReference;
 import org.eclipse.ui.IWorkbenchWindow;
+import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.contexts.IContextService;
 import org.eclipse.ui.handlers.HandlerUtil;
 import org.eclipse.ui.keys.IBindingService;
@@ -185,7 +186,9 @@ public abstract class FilteredTableBaseHandler extends AbstractHandler implement
 
 		/* for issues with dark theme, don't use SWT.SEPARATOR as style */
 		labelSeparator = new Label(composite, SWT.HORIZONTAL);
-		labelSeparator.setBackgroundImage(getSeparatorBgImage());
+		Image separatorBgImage = createSeparatorBgImage();
+		labelSeparator.setBackgroundImage(separatorBgImage);
+		labelSeparator.addDisposeListener(e -> separatorBgImage.dispose());
 		GridData gd_label = new GridData(SWT.FILL, SWT.CENTER, false, false, 1, 1);
 		gd_label.heightHint = 1;
 		labelSeparator.setLayoutData(gd_label);
@@ -316,7 +319,7 @@ public abstract class FilteredTableBaseHandler extends AbstractHandler implement
 	 * Build a 1x1 px gray image to be used as separator. This color, halfway
 	 * between white and black, looks good both in Classic and in Dark Theme
 	 */
-	private Image getSeparatorBgImage() {
+	private Image createSeparatorBgImage() {
 		Image backgroundImage = new Image(Display.getDefault(), 1, 1);
 		GC gc = new GC(backgroundImage);
 		gc.setBackground(new Color(dialog.getDisplay(), 127, 127, 127));
@@ -334,7 +337,7 @@ public abstract class FilteredTableBaseHandler extends AbstractHandler implement
 	private FocusAdapter fAdapter = new FocusAdapter() {
 		@Override
 		public void focusLost(FocusEvent e) {
-			dialog.getDisplay().asyncExec(() -> {
+			PlatformUI.getWorkbench().getDisplay().asyncExec(() -> {
 				// once event complete, if dialog still open..
 				if (dialog.isDisposed()) {
 					return;
@@ -489,7 +492,7 @@ public abstract class FilteredTableBaseHandler extends AbstractHandler implement
 					break;
 				case SWT.DEL:
 					// no filter text, closes selected item
-					if (text.getText().length() == 0) {
+					if (text.getText().isEmpty()) {
 						deleteSelectedItem();
 					}
 					break;
@@ -624,15 +627,13 @@ public abstract class FilteredTableBaseHandler extends AbstractHandler implement
 		int index = table.getSelectionIndex();
 		if (!isFiltered()) {
 			table.setSelection(index >= 1 ? index - 1 : table.getItemCount() - 1);
+		} else if (text.isFocusControl()) {
+			table.setFocus();
+			table.setSelection(index >= 1 ? index - 1 : table.getItemCount() - 1);
+		} else if (index == 0) {
+			text.setFocus();
 		} else {
-			if (text.isFocusControl()) {
-				table.setFocus();
-				table.setSelection(index >= 1 ? index - 1 : table.getItemCount() - 1);
-			} else if (index == 0) {
-				text.setFocus();
-			} else {
-				table.setSelection(index >= 1 ? index - 1 : table.getItemCount() - 1);
-			}
+			table.setSelection(index >= 1 ? index - 1 : table.getItemCount() - 1);
 		}
 	}
 
@@ -817,7 +818,6 @@ public abstract class FilteredTableBaseHandler extends AbstractHandler implement
 	 * can override this method to style the table, using a StyledCellLabelProvider.
 	 *
 	 * @param tableViewerColumn
-	 * @return
 	 */
 	protected void setLabelProvider(TableViewerColumn tableViewerColumn) {
 		tableViewerColumn.setLabelProvider(getColumnLabelProvider());
