@@ -31,7 +31,6 @@ import org.eclipse.ui.IKeyBindingService;
 import org.eclipse.ui.INestableKeyBindingService;
 import org.eclipse.ui.IWorkbenchPartSite;
 import org.eclipse.ui.IWorkbenchSite;
-import org.eclipse.ui.LegacyHandlerSubmissionExpression;
 import org.eclipse.ui.handlers.IHandlerActivation;
 import org.eclipse.ui.handlers.IHandlerService;
 import org.eclipse.ui.internal.actions.CommandAction;
@@ -315,15 +314,6 @@ public final class KeyBindingService implements INestableKeyBindingService {
 
 		unregisterAction(action);
 
-		IWorkbenchPartSite partSite = workbenchPartSite;
-		if (parent != null) {
-			KeyBindingService currentParent = parent;
-			while (currentParent != null) {
-				partSite = currentParent.workbenchPartSite;
-				currentParent = currentParent.parent;
-			}
-		}
-
 		String commandId = action.getActionDefinitionId();
 		if (commandId != null) {
 			for (IAction registeredAction : actionToProxy.keySet()) {
@@ -336,9 +326,7 @@ public final class KeyBindingService implements INestableKeyBindingService {
 			}
 
 			IHandlerService hs = workbenchPartSite.getService(IHandlerService.class);
-			actionToProxy.put(action, hs.activateHandler(commandId, new ActionHandler(action),
-					new LegacyHandlerSubmissionExpression(null, partSite.getShell(), partSite)));
-
+			actionToProxy.put(action, hs.activateHandler(commandId, new ActionHandler(action)));
 		}
 	}
 
