@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -72,7 +72,7 @@ import org.eclipse.ui.internal.WorkbenchImages;
 import org.eclipse.ui.internal.WorkbenchMessages;
 import org.eclipse.ui.internal.WorkbenchPlugin;
 import org.eclipse.ui.internal.misc.StatusUtil;
-import org.eclipse.ui.internal.misc.StringMatcher;
+import org.eclipse.ui.internal.misc.TextMatcher;
 import org.eclipse.ui.internal.util.BundleUtility;
 import org.eclipse.ui.progress.WorkbenchJob;
 import org.eclipse.ui.statushandlers.StatusManager;
@@ -85,8 +85,7 @@ import org.osgi.framework.Bundle;
  */
 public class AboutPluginsPage extends ProductInfoPage {
 
-	public class BundleTableLabelProvider extends LabelProvider implements
-			ITableLabelProvider {
+	public class BundleTableLabelProvider extends LabelProvider implements ITableLabelProvider {
 
 		/**
 		 * Queue containing bundle signing info to be resolved.
@@ -99,8 +98,8 @@ public class AboutPluginsPage extends ProductInfoPage {
 		private List<AboutBundleData> updateQueue = new ArrayList<>();
 
 		/*
-		 * this job will attempt to discover the signing state of a given bundle
-		 * and then send it along to the update job
+		 * this job will attempt to discover the signing state of a given bundle and
+		 * then send it along to the update job
 		 */
 		private Job resolveJob = new Job(AboutPluginsPage.class.getName()) {
 			{
@@ -144,11 +143,11 @@ public class AboutPluginsPage extends ProductInfoPage {
 		};
 
 		/*
-		 * this job is responsible for feeding label change events into the
-		 * viewer as they become available from the resolve job
+		 * this job is responsible for feeding label change events into the viewer as
+		 * they become available from the resolve job
 		 */
-		private Job updateJob = new WorkbenchJob(PlatformUI.getWorkbench()
-				.getDisplay(), AboutPluginsPage.class.getName()) {
+		private Job updateJob = new WorkbenchJob(PlatformUI.getWorkbench().getDisplay(),
+				AboutPluginsPage.class.getName()) {
 			{
 				setSystem(true);
 				setPriority(Job.DECORATE);
@@ -166,13 +165,11 @@ public class AboutPluginsPage extends ProductInfoPage {
 						if (updateQueue.isEmpty())
 							return Status.OK_STATUS;
 
-						data = updateQueue
-								.toArray(new AboutBundleData[updateQueue.size()]);
+						data = updateQueue.toArray(new AboutBundleData[updateQueue.size()]);
 						updateQueue.clear();
 
 					}
-					fireLabelProviderChanged(new LabelProviderChangedEvent(
-							BundleTableLabelProvider.this, data));
+					fireLabelProviderChanged(new LabelProviderChangedEvent(BundleTableLabelProvider.this, data));
 				}
 			}
 		};
@@ -183,9 +180,8 @@ public class AboutPluginsPage extends ProductInfoPage {
 				if (element instanceof AboutBundleData) {
 					final AboutBundleData data = (AboutBundleData) element;
 					if (data.isSignedDetermined()) {
-						return WorkbenchImages
-								.getImage(data.isSigned() ? IWorkbenchGraphicConstants.IMG_OBJ_SIGNED_YES
-										: IWorkbenchGraphicConstants.IMG_OBJ_SIGNED_NO);
+						return WorkbenchImages.getImage(data.isSigned() ? IWorkbenchGraphicConstants.IMG_OBJ_SIGNED_YES
+								: IWorkbenchGraphicConstants.IMG_OBJ_SIGNED_NO);
 					}
 
 					synchronized (resolveQueue) {
@@ -193,8 +189,7 @@ public class AboutPluginsPage extends ProductInfoPage {
 					}
 					resolveJob.schedule();
 
-					return WorkbenchImages
-							.getImage(IWorkbenchGraphicConstants.IMG_OBJ_SIGNED_UNKNOWN);
+					return WorkbenchImages.getImage(IWorkbenchGraphicConstants.IMG_OBJ_SIGNED_UNKNOWN);
 				}
 			}
 			return null;
@@ -247,12 +242,9 @@ public class AboutPluginsPage extends ProductInfoPage {
 
 	private String helpContextId = IWorkbenchHelpContextIds.ABOUT_PLUGINS_DIALOG;
 
-	private String columnTitles[] = {
-			WorkbenchMessages.AboutPluginsDialog_signed,
-			WorkbenchMessages.AboutPluginsDialog_provider,
-			WorkbenchMessages.AboutPluginsDialog_pluginName,
-			WorkbenchMessages.AboutPluginsDialog_version,
-			WorkbenchMessages.AboutPluginsDialog_pluginId,
+	private String columnTitles[] = { WorkbenchMessages.AboutPluginsDialog_signed,
+			WorkbenchMessages.AboutPluginsDialog_provider, WorkbenchMessages.AboutPluginsDialog_pluginName,
+			WorkbenchMessages.AboutPluginsDialog_version, WorkbenchMessages.AboutPluginsDialog_pluginId,
 
 	};
 	private Bundle[] bundles = WorkbenchPlugin.getDefault().getBundles();
@@ -281,15 +273,12 @@ public class AboutPluginsPage extends ProductInfoPage {
 			signingArea.setData(bundleInfo);
 
 			signingArea.createContents(sashForm);
-			sashForm.setWeights(new int[] { 100 - SIGNING_AREA_PERCENTAGE,
-					SIGNING_AREA_PERCENTAGE });
-			signingInfo
-					.setText(WorkbenchMessages.AboutPluginsDialog_signingInfo_hide);
+			sashForm.setWeights(new int[] { 100 - SIGNING_AREA_PERCENTAGE, SIGNING_AREA_PERCENTAGE });
+			signingInfo.setText(WorkbenchMessages.AboutPluginsDialog_signingInfo_hide);
 
 		} else {
 			// hide
-			signingInfo
-					.setText(WorkbenchMessages.AboutPluginsDialog_signingInfo_show);
+			signingInfo.setText(WorkbenchMessages.AboutPluginsDialog_signingInfo_show);
 			signingArea.dispose();
 			signingArea = null;
 			sashForm.setWeights(new int[] { 100 });
@@ -299,16 +288,13 @@ public class AboutPluginsPage extends ProductInfoPage {
 	@Override
 	public void createPageButtons(Composite parent) {
 
-		moreInfo = createButton(parent, MORE_ID,
-				WorkbenchMessages.AboutPluginsDialog_moreInfo);
+		moreInfo = createButton(parent, MORE_ID, WorkbenchMessages.AboutPluginsDialog_moreInfo);
 		moreInfo.setEnabled(false);
 
-		signingInfo = createButton(parent, SIGNING_ID,
-				WorkbenchMessages.AboutPluginsDialog_signingInfo_show);
+		signingInfo = createButton(parent, SIGNING_ID, WorkbenchMessages.AboutPluginsDialog_signingInfo_show);
 		signingInfo.setEnabled(false);
 
-		createButton(parent, COLUMNS_ID,
-				WorkbenchMessages.AboutPluginsDialog_columns);
+		createButton(parent, COLUMNS_ID, WorkbenchMessages.AboutPluginsDialog_columns);
 	}
 
 	@Override
@@ -362,17 +348,16 @@ public class AboutPluginsPage extends ProductInfoPage {
 	/**
 	 * Create the table part of the dialog.
 	 *
-	 * @param parent
-	 *            the parent composite to contain the dialog area
+	 * @param parent the parent composite to contain the dialog area
 	 */
 	protected void createTable(Composite parent) {
-		final Text filterText = new Text(parent, SWT.BORDER | SWT.SEARCH | SWT.ICON_CANCEL);
+		final Text filterText = new Text(parent, SWT.BORDER | SWT.SEARCH | SWT.ICON_CANCEL | SWT.ICON_SEARCH);
 		filterText.setLayoutData(GridDataFactory.fillDefaults().create());
 		filterText.setMessage(WorkbenchMessages.AboutPluginsDialog_filterTextMessage);
 		filterText.setFocus();
 
-		vendorInfo = new TableViewer(parent, SWT.H_SCROLL | SWT.V_SCROLL
-				| SWT.SINGLE | SWT.FULL_SELECTION | SWT.BORDER);
+		vendorInfo = new TableViewer(parent,
+				SWT.H_SCROLL | SWT.V_SCROLL | SWT.SINGLE | SWT.FULL_SELECTION | SWT.BORDER);
 		vendorInfo.setUseHashlookup(true);
 		vendorInfo.getTable().setHeaderVisible(true);
 		vendorInfo.getTable().setLinesVisible(true);
@@ -381,17 +366,13 @@ public class AboutPluginsPage extends ProductInfoPage {
 
 		final TableComparator comparator = new TableComparator();
 		vendorInfo.setComparator(comparator);
-		int[] columnWidths = {
-				convertHorizontalDLUsToPixels(30), // signature
-				convertHorizontalDLUsToPixels(120),
-				convertHorizontalDLUsToPixels(120),
-				convertHorizontalDLUsToPixels(70),
-				convertHorizontalDLUsToPixels(130), };
+		int[] columnWidths = { convertHorizontalDLUsToPixels(30), // signature
+				convertHorizontalDLUsToPixels(120), convertHorizontalDLUsToPixels(120),
+				convertHorizontalDLUsToPixels(70), convertHorizontalDLUsToPixels(130), };
 
 		// create table headers
 		for (int i = 0; i < columnTitles.length; i++) {
-			TableColumn column = new TableColumn(vendorInfo.getTable(),
-					SWT.NULL);
+			TableColumn column = new TableColumn(vendorInfo.getTable(), SWT.NULL);
 			if (i == PLUGIN_NAME_COLUMN_INDEX) { // prime initial sorting
 				updateTableSorting(i);
 			}
@@ -401,18 +382,22 @@ public class AboutPluginsPage extends ProductInfoPage {
 			column.addSelectionListener(widgetSelectedAdapter(e -> updateTableSorting(columnIndex)));
 		}
 
-		vendorInfo.setContentProvider(new ArrayContentProvider());
+		vendorInfo.setContentProvider(ArrayContentProvider.getInstance());
 		vendorInfo.setLabelProvider(new BundleTableLabelProvider());
 
 		final BundlePatternFilter searchFilter = new BundlePatternFilter();
 		filterText.addModifyListener(e -> {
 			searchFilter.setPattern(filterText.getText());
-			vendorInfo.refresh();
+			vendorInfo.getTable().setRedraw(false);
+			try {
+				vendorInfo.refresh();
+			} finally {
+				vendorInfo.getTable().setRedraw(true);
+			}
 		});
 		vendorInfo.addFilter(searchFilter);
 
-		GridData gridData = new GridData(GridData.FILL, GridData.FILL, true,
-				true);
+		GridData gridData = new GridData(GridData.FILL, GridData.FILL, true, true);
 		gridData.heightHint = convertVerticalDLUsToPixels(TABLE_HEIGHT);
 		vendorInfo.getTable().setLayoutData(gridData);
 
@@ -421,39 +406,35 @@ public class AboutPluginsPage extends ProductInfoPage {
 				vendorInfo.setInput(bundleData);
 			}
 		}, parent.getDisplay());
+
+		addCopySupport(vendorInfo.getTable());
 	}
 
 	/**
 	 * Update the sort information on both the comparator and the table.
 	 *
-	 * @param columnIndex
-	 *            the index to sort by
+	 * @param columnIndex the index to sort by
 	 * @since 3.4
 	 */
 	private void updateTableSorting(final int columnIndex) {
-		TableComparator comparator = (TableComparator) vendorInfo
-				.getComparator();
+		TableComparator comparator = (TableComparator) vendorInfo.getComparator();
 		// toggle direction if it's the same column
 		if (columnIndex == comparator.getSortColumn()) {
 			comparator.setAscending(!comparator.isAscending());
 		}
 		comparator.setSortColumn(columnIndex);
-		vendorInfo.getTable().setSortColumn(
-				vendorInfo.getTable().getColumn(columnIndex));
-		vendorInfo.getTable().setSortDirection(
-				comparator.isAscending() ? SWT.UP : SWT.DOWN);
+		vendorInfo.getTable().setSortColumn(vendorInfo.getTable().getColumn(columnIndex));
+		vendorInfo.getTable().setSortDirection(comparator.isAscending() ? SWT.UP : SWT.DOWN);
 		vendorInfo.refresh(false);
 	}
 
 	/**
-	 * Return an URL to the plugin's about.html file (what is shown when
-	 * "More info" is pressed) or null if no such file exists. The method does
-	 * nl lookup to allow for i18n.
+	 * Return an URL to the plugin's about.html file (what is shown when "More info"
+	 * is pressed) or null if no such file exists. The method does nl lookup to
+	 * allow for i18n.
 	 *
-	 * @param bundleInfo
-	 *            the bundle info
-	 * @param makeLocal
-	 *            whether to make the about content local
+	 * @param bundleInfo the bundle info
+	 * @param makeLocal  whether to make the about content local
 	 * @return the URL or <code>null</code>
 	 */
 	private URL getMoreInfoURL(AboutBundleData bundleInfo, boolean makeLocal) {
@@ -500,8 +481,7 @@ public class AboutPluginsPage extends ProductInfoPage {
 		// item has additional info
 		IStructuredSelection selection = vendorInfo.getStructuredSelection();
 		if (selection.getFirstElement() instanceof AboutBundleData) {
-			AboutBundleData selected = (AboutBundleData) selection
-					.getFirstElement();
+			AboutBundleData selected = (AboutBundleData) selection.getFirstElement();
 			moreInfo.setEnabled(selectionHasInfo(selected));
 			signingInfo.setEnabled(true);
 			if (signingArea != null) {
@@ -532,13 +512,11 @@ public class AboutPluginsPage extends ProductInfoPage {
 	}
 
 	/**
-	 * Check if the currently selected plugin has additional information to
-	 * show.
+	 * Check if the currently selected plugin has additional information to show.
 	 *
 	 * @param bundleInfo
 	 *
-	 * @return true if the selected plugin has additional info available to
-	 *         display
+	 * @return true if the selected plugin has additional info available to display
 	 */
 	private boolean selectionHasInfo(AboutBundleData bundleInfo) {
 
@@ -555,8 +533,8 @@ public class AboutPluginsPage extends ProductInfoPage {
 
 	/**
 	 * The More Info button was pressed. Open a browser showing the license
-	 * information for the selected bundle or an error dialog if the browser
-	 * cannot be opened.
+	 * information for the selected bundle or an error dialog if the browser cannot
+	 * be opened.
 	 */
 	protected void handleMoreInfoPressed() {
 		if (vendorInfo == null) {
@@ -568,14 +546,11 @@ public class AboutPluginsPage extends ProductInfoPage {
 
 		AboutBundleData bundleInfo = (AboutBundleData) vendorInfo.getStructuredSelection().getFirstElement();
 
-		if (!AboutUtils.openBrowser(getShell(),
-				getMoreInfoURL(bundleInfo, true))) {
-			String message = NLS.bind(
-					WorkbenchMessages.AboutPluginsDialog_unableToOpenFile,
-					PLUGININFO, bundleInfo.getId());
-			StatusUtil.handleStatus(
-					WorkbenchMessages.AboutPluginsDialog_errorTitle
-							+ ": " + message, StatusManager.SHOW, getShell()); //$NON-NLS-1$
+		if (!AboutUtils.openBrowser(getShell(), getMoreInfoURL(bundleInfo, true))) {
+			String message = NLS.bind(WorkbenchMessages.AboutPluginsDialog_unableToOpenFile, PLUGININFO,
+					bundleInfo.getId());
+			StatusUtil.handleStatus(WorkbenchMessages.AboutPluginsDialog_errorTitle + ": " + message, //$NON-NLS-1$
+					StatusManager.SHOW);
 		}
 	}
 
@@ -596,8 +571,7 @@ class TableComparator extends ViewerComparator {
 
 	@Override
 	public int compare(Viewer viewer, Object e1, Object e2) {
-		if (sortColumn == 0 && e1 instanceof AboutBundleData
-				&& e2 instanceof AboutBundleData) {
+		if (sortColumn == 0 && e1 instanceof AboutBundleData && e2 instanceof AboutBundleData) {
 			AboutBundleData d1 = (AboutBundleData) e1;
 			AboutBundleData d2 = (AboutBundleData) e2;
 			int diff = getSignedSortValue(d1) - getSignedSortValue(d2);
@@ -611,10 +585,8 @@ class TableComparator extends ViewerComparator {
 				IBaseLabelProvider baseLabel = tableViewer.getLabelProvider();
 				if (baseLabel instanceof ITableLabelProvider) {
 					ITableLabelProvider tableProvider = (ITableLabelProvider) baseLabel;
-					String e1p = tableProvider
-							.getColumnText(e1, lastSortColumn);
-					String e2p = tableProvider
-							.getColumnText(e2, lastSortColumn);
+					String e1p = tableProvider.getColumnText(e1, lastSortColumn);
+					String e2p = tableProvider.getColumnText(e2, lastSortColumn);
 					int result = getComparator().compare(e1p, e2p);
 					return lastAscending ? result : (-1) * result;
 				}
@@ -638,12 +610,10 @@ class TableComparator extends ViewerComparator {
 						result = getComparator().compare(e1p, e2p);
 						return lastAscending ? result : (-1) * result;
 					} // secondary sort is by column 0
-					if (e1 instanceof AboutBundleData
-							&& e2 instanceof AboutBundleData) {
+					if (e1 instanceof AboutBundleData && e2 instanceof AboutBundleData) {
 						AboutBundleData d1 = (AboutBundleData) e1;
 						AboutBundleData d2 = (AboutBundleData) e2;
-						int diff = getSignedSortValue(d1)
-								- getSignedSortValue(d2);
+						int diff = getSignedSortValue(d1) - getSignedSortValue(d2);
 						return lastAscending ? diff : -diff;
 					}
 				}
@@ -677,8 +647,7 @@ class TableComparator extends ViewerComparator {
 	}
 
 	/**
-	 * @param sortColumn
-	 *            The sortColumn to set.
+	 * @param sortColumn The sortColumn to set.
 	 */
 	public void setSortColumn(int sortColumn) {
 		if (this.sortColumn != sortColumn) {
@@ -696,8 +665,7 @@ class TableComparator extends ViewerComparator {
 	}
 
 	/**
-	 * @param ascending
-	 *            The ascending to set.
+	 * @param ascending The ascending to set.
 	 */
 	public void setAscending(boolean ascending) {
 		this.ascending = ascending;
@@ -706,14 +674,14 @@ class TableComparator extends ViewerComparator {
 
 class BundlePatternFilter extends ViewerFilter {
 
-	private StringMatcher matcher;
+	private TextMatcher matcher;
 
 	public void setPattern(String searchPattern) {
-		if (searchPattern == null || searchPattern.length() == 0) {
+		if (searchPattern == null || searchPattern.isEmpty()) {
 			this.matcher = null;
 		} else {
 			String pattern = "*" + searchPattern + "*"; //$NON-NLS-1$//$NON-NLS-2$
-			this.matcher = new StringMatcher(pattern, true, false);
+			this.matcher = new TextMatcher(pattern, true, false);
 		}
 	}
 
