@@ -20,10 +20,9 @@ import org.eclipse.ui.internal.WorkbenchPlugin;
 import org.eclipse.ui.internal.preferences.WorkbenchPreferenceExpressionNode;
 
 /**
- * This class is created to avoid mentioning preferences
- * in this context. Ideally, JFace preference classes should be
- * renamed into something more generic (for example,
- * 'TreeNavigationDialog').
+ * This class is created to avoid mentioning preferences in this context.
+ * Ideally, JFace preference classes should be renamed into something more
+ * generic (for example, 'TreeNavigationDialog').
  */
 
 public class PropertyPageManager extends PreferenceManager {
@@ -31,8 +30,7 @@ public class PropertyPageManager extends PreferenceManager {
 	 * The constructor.
 	 */
 	public PropertyPageManager() {
-		super(WorkbenchPlugin.PREFERENCE_PAGE_CATEGORY_SEPARATOR,
-				new WorkbenchPreferenceExpressionNode("")); //$NON-NLS-1$
+		super(WorkbenchPlugin.PREFERENCE_PAGE_CATEGORY_SEPARATOR, new WorkbenchPreferenceExpressionNode("")); //$NON-NLS-1$
 	}
 
 }
