@@ -14,6 +14,7 @@
  *     Lars Vogel <Lars.Vogel@vogella.com> - Bug 445664, 442278, 472654
  *     Andrey Loskutov <loskutov@gmx.de> - Bug 388476
  *     Patrik Suzzi - <psuzzi@gmail.com> - Bug 515265
+ *     Kit Lo - <kitlo@us.ibm.com> - Bug 572444
  *******************************************************************************/
 
 package org.eclipse.ui.internal.dialogs;
@@ -25,9 +26,11 @@ import static org.eclipse.ui.internal.registry.IWorkbenchRegistryConstants.ATT_O
 import static org.eclipse.ui.internal.registry.IWorkbenchRegistryConstants.ATT_THEME_ASSOCIATION;
 import static org.eclipse.ui.internal.registry.IWorkbenchRegistryConstants.ATT_THEME_ID;
 
+import java.text.Collator;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
+import java.util.Locale;
 import java.util.Map;
 import java.util.Objects;
 import org.eclipse.core.runtime.IConfigurationElement;
@@ -199,7 +202,8 @@ public class ViewsPreferencePage extends PreferencePage implements IWorkbenchPre
 			}
 			themes.add(theme);
 		}
-		themes.sort((ITheme t1, ITheme t2) -> t1.getLabel().compareTo(t2.getLabel()));
+		Collator collator = Collator.getInstance(Locale.getDefault());
+		themes.sort((ITheme t1, ITheme t2) -> collator.compare(t1.getLabel(), t2.getLabel()));
 		return themes;
 	}
 
@@ -532,7 +536,7 @@ public class ViewsPreferencePage extends PreferencePage implements IWorkbenchPre
 			parent.setLayout(new RowLayout());
 
 			Link link = new Link(parent, SWT.WRAP);
-			link.setText(WorkbenchMessages.ThemeChangeWarningText);
+			link.setText(WorkbenchMessages.ThemeChangeWarningHyperlinkedText);
 			link.addSelectionListener(widgetSelectedAdapter(e -> PlatformUI.getWorkbench().restart(true)));
 		}
 	}
