@@ -14,7 +14,6 @@
 package org.eclipse.ui.internal.dialogs;
 
 import org.eclipse.core.runtime.Assert;
-import org.eclipse.jface.dialogs.IDialogSettings;
 import org.eclipse.jface.preference.IPreferenceNode;
 import org.eclipse.jface.preference.PreferenceManager;
 import org.eclipse.swt.widgets.Shell;
@@ -23,7 +22,6 @@ import org.eclipse.ui.IWorkbenchWindow;
 import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.activities.WorkbenchActivityHelper;
 import org.eclipse.ui.internal.IWorkbenchHelpContextIds;
-import org.eclipse.ui.internal.WorkbenchPlugin;
 
 /**
  * Prefence dialog for the workbench including the ability to load/save
@@ -39,16 +37,6 @@ public class WorkbenchPreferenceDialog extends FilteredPreferenceDialog {
 	 */
 	private static WorkbenchPreferenceDialog instance = null;
 
-	/**
-	 * The bounds of this dialog will be persisted in the dialog settings. This is
-	 * defined at the most concrete level of the hierarchy so that different
-	 * concrete implementations don't necessarily store their bounds in the same
-	 * settings.
-	 *
-	 * @since 3.2
-	 */
-	private static final String DIALOG_SETTINGS_SECTION = "WorkbenchPreferenceDialogSettings"; //$NON-NLS-1$
-
 	/**
 	 * Creates a workbench preference dialog to a particular preference page. It is
 	 * the responsibility of the caller to then call <code>open()</code>. The call
@@ -153,30 +141,4 @@ public class WorkbenchPreferenceDialog extends FilteredPreferenceDialog {
 		return node;
 	}
 
-	@Override
-	protected void okPressed() {
-		super.okPressed();
-	}
-
-	@Override
-	protected IDialogSettings getDialogBoundsSettings() {
-		IDialogSettings settings = WorkbenchPlugin.getDefault().getDialogSettings();
-		IDialogSettings section = settings.getSection(DIALOG_SETTINGS_SECTION);
-		if (section == null) {
-			section = settings.addNewSection(DIALOG_SETTINGS_SECTION);
-		}
-		return section;
-	}
-
-	/**
-	 * Overridden to persist only the location, not the size, since the current page
-	 * dictates the most appropriate size for the dialog.
-	 *
-	 * @since 3.2
-	 */
-	@Override
-	protected int getDialogBoundsStrategy() {
-		return DIALOG_PERSISTLOCATION;
-	}
-
 }
