@@ -218,12 +218,10 @@ class ItemDetailToolTip extends NameAndDescriptionToolTip {
 					} else {
 						text = NLS.bind(WorkbenchMessages.HideItems_keyBindingsActionSetUnavailable, keybindings);
 					}
+				} else if (available) {
+					text = WorkbenchMessages.HideItems_noKeyBindings;
 				} else {
-					if (available) {
-						text = WorkbenchMessages.HideItems_noKeyBindings;
-					} else {
-						text = WorkbenchMessages.HideItems_noKeyBindingsActionSetUnavailable;
-					}
+					text = WorkbenchMessages.HideItems_noKeyBindingsActionSetUnavailable;
 				}
 
 				// Construct link to go to the preferences page for key
@@ -400,8 +398,6 @@ class ItemDetailToolTip extends NameAndDescriptionToolTip {
 			}
 		}
 
-		Binding[] bindings = foundBindings.toArray(new Binding[foundBindings.size()]);
-
-		return bindings;
+		return foundBindings.toArray(new Binding[foundBindings.size()]);
 	}
 }
\ No newline at end of file
