@@ -69,7 +69,9 @@ public class E4HandlerProxy implements IHandler2, IHandlerListener, IElementUpda
 		if (handler instanceof IHandler2) {
 			Object ctx = staticContext;
 			if (ctx == null) {
-				ctx = new ExpressionContext(application.getContext());
+				if (context != null) {
+					ctx = new ExpressionContext(context != null ? context : application.getContext());
+				}
 			}
 			((IHandler2) handler).setEnabled(ctx);
 		}
@@ -92,8 +94,7 @@ public class E4HandlerProxy implements IHandler2, IHandlerListener, IElementUpda
 				appContext);
 		if (handler != null) {
 			if (handler.isHandled()) {
-				final Object returnValue = handler.execute(event);
-				return returnValue;
+				return handler.execute(event);
 			}
 			throw new NotHandledException("Handler " + handler //$NON-NLS-1$
 					+ " is not handled for for command " + command); //$NON-NLS-1$
