@@ -18,8 +18,6 @@ import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.Status;
 import org.eclipse.jface.dialogs.IconAndMessageDialog;
 import org.eclipse.jface.resource.JFaceResources;
-import org.eclipse.jface.viewers.Viewer;
-import org.eclipse.jface.viewers.ViewerComparator;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.layout.GridData;
@@ -74,7 +72,7 @@ public class BlockedJobsDialog extends IconAndMessageDialog {
 
 		@Override
 		String getDisplayString() {
-			if (blockedTaskName == null || blockedTaskName.length() == 0) {
+			if (blockedTaskName == null || blockedTaskName.isEmpty()) {
 				return ProgressMessages.BlockedJobsDialog_UserInterfaceTreeElement;
 			}
 			return blockedTaskName;
@@ -136,7 +134,7 @@ public class BlockedJobsDialog extends IconAndMessageDialog {
 		}
 		singleton = new BlockedJobsDialog(parentShell, blockedMonitor, reason);
 
-		if (taskName == null || taskName.length() == 0) {
+		if (taskName == null || taskName.isEmpty()) {
 			singleton.setBlockedTaskName(ProgressMessages.BlockedJobsDialog_UserInterfaceTreeElement);
 		} else {
 			singleton.setBlockedTaskName(taskName);
@@ -223,13 +221,7 @@ public class BlockedJobsDialog extends IconAndMessageDialog {
 	 */
 	void showJobDetails(Composite parent) {
 		viewer = new DetailedProgressViewer(parent, SWT.MULTI | SWT.H_SCROLL | SWT.V_SCROLL | SWT.BORDER);
-		viewer.setComparator(new ViewerComparator() {
-			@Override
-			@SuppressWarnings("unchecked")
-			public int compare(Viewer testViewer, Object e1, Object e2) {
-				return ((Comparable<Object>) e1).compareTo(e2);
-			}
-		});
+		viewer.setComparator(ProgressManagerUtil.getProgressViewerComparator());
 		ProgressViewerContentProvider provider = getContentProvider();
 		viewer.setContentProvider(provider);
 		viewer.setInput(provider);
@@ -270,7 +262,7 @@ public class BlockedJobsDialog extends IconAndMessageDialog {
 	/**
 	 * Clears the cursor on the supplied control.
 	 *
-	 * @param control
+	 * @param control the control where custom cursor is removed
 	 */
 	private void clearCursor(Control control) {
 		if (control != null && !control.isDisposed()) {
@@ -306,7 +298,7 @@ public class BlockedJobsDialog extends IconAndMessageDialog {
 
 	/**
 	 * Returns the progress monitor being used for this dialog. This allows
-	 * recursive blockages to also respond to cancelation.
+	 * recursive blockages to also respond to cancellation.
 	 *
 	 * @return IProgressMonitor
 	 */
@@ -318,8 +310,9 @@ public class BlockedJobsDialog extends IconAndMessageDialog {
 	 * Requests that the blocked jobs dialog be closed. The supplied monitor must be
 	 * the same one that was passed to the createBlockedDialog method.
 	 *
-	 * @param monitor
-	 * @return IProgressMonitor
+	 * @param monitor the monitor associated with this block dialog. Dialog will not
+	 *                close if it is another monitor.
+	 * @return <code>true</code> if successfully closed
 	 */
 	public boolean close(IProgressMonitor monitor) {
 		// ignore requests to close the dialog from all but the first monitor
