@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2004, 2015 IBM Corporation and others.
+ * Copyright (c) 2004, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -17,13 +17,10 @@ import static org.eclipse.swt.events.SelectionListener.widgetSelectedAdapter;
 
 import java.lang.reflect.InvocationTargetException;
 import org.eclipse.core.runtime.IProgressMonitor;
-import org.eclipse.core.runtime.IProgressMonitorWithBlocking;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.jface.dialogs.ProgressMonitorDialog;
 import org.eclipse.jface.operation.IRunnableWithProgress;
-import org.eclipse.jface.viewers.Viewer;
-import org.eclipse.jface.viewers.ViewerComparator;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.graphics.Cursor;
 import org.eclipse.swt.graphics.Point;
@@ -55,18 +52,21 @@ public class ProgressMonitorJobsDialog extends ProgressMonitorDialog {
 
 	private long watchTime = -1;
 
+	/** Flag to prevent nested closes. */
 	protected boolean alreadyClosed = false;
 
 	private IProgressMonitor wrapperedMonitor;
 
-	// Cache initial enablement in case the enablement state is set
-	// before the button is created
+	/**
+	 * Cache initial enablement in case the enablement state is set before the
+	 * button is created
+	 */
 	protected boolean enableDetailsButton = false;
 
 	/**
 	 * Create a new instance of the receiver.
 	 *
-	 * @param parent
+	 * @param parent dialogs parent shell
 	 */
 	public ProgressMonitorJobsDialog(Shell parent) {
 		super(parent);
@@ -81,8 +81,8 @@ public class ProgressMonitorJobsDialog extends ProgressMonitorDialog {
 
 	/**
 	 * Create the extensions to the dialog area.
-	 * 
-	 * @param parent
+	 *
+	 * @param parent the parent composite
 	 */
 	protected void createExtendedDialogArea(Composite parent) {
 		viewerComposite = new Composite(parent, SWT.NONE);
@@ -99,7 +99,6 @@ public class ProgressMonitorJobsDialog extends ProgressMonitorDialog {
 	/**
 	 * The details button has been selected. Open or close the progress viewer as
 	 * appropriate.
-	 *
 	 */
 	void handleDetailsButtonSelect() {
 		Shell shell = getShell();
@@ -119,13 +118,7 @@ public class ProgressMonitorJobsDialog extends ProgressMonitorDialog {
 			}
 
 			viewer = new DetailedProgressViewer(viewerComposite, SWT.MULTI | SWT.H_SCROLL | SWT.V_SCROLL | SWT.BORDER);
-			viewer.setComparator(new ViewerComparator() {
-				@SuppressWarnings({ "unchecked", "rawtypes" })
-				@Override
-				public int compare(Viewer testViewer, Object e1, Object e2) {
-					return ((Comparable) e1).compareTo(e2);
-				}
-			});
+			viewer.setComparator(ProgressManagerUtil.getProgressViewerComparator());
 
 			viewer.setContentProvider(new ProgressViewerContentProvider(viewer, true, false) {
 				@Override
@@ -261,7 +254,7 @@ public class ProgressMonitorJobsDialog extends ProgressMonitorDialog {
 	 *
 	 */
 	public void createWrapperedMonitor() {
-		wrapperedMonitor = new IProgressMonitorWithBlocking() {
+		wrapperedMonitor = new IProgressMonitor() {
 
 			IProgressMonitor superMonitor = ProgressMonitorJobsDialog.super.getProgressMonitor();
 
@@ -351,19 +344,14 @@ public class ProgressMonitorJobsDialog extends ProgressMonitorDialog {
 			@Override
 			public void clearBlocked() {
 				// We want to open on blocking too
-				if (superMonitor instanceof IProgressMonitorWithBlocking) {
-					((IProgressMonitorWithBlocking) superMonitor).clearBlocked();
-				}
+				superMonitor.clearBlocked();
 
 			}
 
 			@Override
 			public void setBlocked(IStatus reason) {
 				openDialog();
-				if (superMonitor instanceof IProgressMonitorWithBlocking) {
-					((IProgressMonitorWithBlocking) superMonitor).setBlocked(reason);
-				}
-
+				superMonitor.setBlocked(reason);
 			}
 
 		};
