@@ -47,8 +47,8 @@ public abstract class MultiEditor extends AbstractMultiEditor {
 
 	/**
 	 * Updates the gradient in the title bar.
-	 * 
-	 * @param editor
+	 *
+	 * @param editor the editor to update; not <code>null</code>
 	 */
 	public void updateGradient(IEditorPart editor) {
 		boolean activeEditor = editor == getSite().getPage().getActiveEditor();
@@ -63,18 +63,16 @@ public abstract class MultiEditor extends AbstractMultiEditor {
 			g.bgColors = new Color[2];
 			g.bgColors[0] = colorRegistry.get(IWorkbenchThemeConstants.ACTIVE_TAB_BG_START);
 			g.bgColors[1] = colorRegistry.get(IWorkbenchThemeConstants.ACTIVE_TAB_BG_END);
+		} else if (activeEditor) {
+			g.fgColor = colorRegistry.get(IWorkbenchThemeConstants.ACTIVE_TAB_TEXT_COLOR);
+			g.bgColors = new Color[2];
+			g.bgColors[0] = colorRegistry.get(IWorkbenchThemeConstants.ACTIVE_TAB_BG_START);
+			g.bgColors[1] = colorRegistry.get(IWorkbenchThemeConstants.ACTIVE_TAB_BG_END);
 		} else {
-			if (activeEditor) {
-				g.fgColor = colorRegistry.get(IWorkbenchThemeConstants.ACTIVE_TAB_TEXT_COLOR);
-				g.bgColors = new Color[2];
-				g.bgColors[0] = colorRegistry.get(IWorkbenchThemeConstants.ACTIVE_TAB_BG_START);
-				g.bgColors[1] = colorRegistry.get(IWorkbenchThemeConstants.ACTIVE_TAB_BG_END);
-			} else {
-				g.fgColor = colorRegistry.get(IWorkbenchThemeConstants.INACTIVE_TAB_TEXT_COLOR);
-				g.bgColors = new Color[2];
-				g.bgColors[0] = colorRegistry.get(IWorkbenchThemeConstants.INACTIVE_TAB_BG_START);
-				g.bgColors[1] = colorRegistry.get(IWorkbenchThemeConstants.INACTIVE_TAB_BG_END);
-			}
+			g.fgColor = colorRegistry.get(IWorkbenchThemeConstants.INACTIVE_TAB_TEXT_COLOR);
+			g.bgColors = new Color[2];
+			g.bgColors[0] = colorRegistry.get(IWorkbenchThemeConstants.INACTIVE_TAB_BG_START);
+			g.bgColors[1] = colorRegistry.get(IWorkbenchThemeConstants.INACTIVE_TAB_BG_END);
 		}
 		g.bgPercents = new int[] { theme.getInt(IWorkbenchThemeConstants.ACTIVE_TAB_PERCENT) };
 
