@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2016 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -12,45 +12,34 @@
  *     IBM Corporation - initial API and implementation
  *     Lars Vogel <Lars.Vogel@vogella.com> - Bug 481319, 481318
  *     Philipp Kunz <philipp.kunz@paratix.ch> - Bug 297922
+ *     Alexander Fedorov <alexander.fedorov@arsysop.ru> - Bug 520080, 549861
  *******************************************************************************/
 package org.eclipse.ui.plugin;
 
-import java.io.BufferedReader;
-import java.io.File;
-import java.io.IOException;
-import java.io.InputStreamReader;
-import java.net.MalformedURLException;
-import java.net.URI;
-import java.net.URISyntaxException;
-import java.net.URL;
-import java.nio.charset.StandardCharsets;
 import org.eclipse.core.runtime.CoreException;
-import org.eclipse.core.runtime.FileLocator;
-import org.eclipse.core.runtime.IPath;
-import org.eclipse.core.runtime.IStatus;
-import org.eclipse.core.runtime.Path;
 import org.eclipse.core.runtime.Platform;
 import org.eclipse.core.runtime.Plugin;
-import org.eclipse.core.runtime.Status;
 import org.eclipse.core.runtime.preferences.InstanceScope;
-import org.eclipse.jface.dialogs.DialogSettings;
 import org.eclipse.jface.dialogs.IDialogSettings;
+import org.eclipse.jface.dialogs.IDialogSettingsProvider;
 import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.jface.resource.ImageDescriptor;
 import org.eclipse.jface.resource.ImageRegistry;
+import org.eclipse.jface.resource.ResourceLocator;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.SWTError;
 import org.eclipse.swt.widgets.Display;
+import org.eclipse.ui.ISharedImages;
 import org.eclipse.ui.IWorkbench;
 import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.internal.WWinPluginAction;
-import org.eclipse.ui.internal.WorkbenchPlugin;
 import org.eclipse.ui.internal.util.BundleUtility;
 import org.eclipse.ui.preferences.ScopedPreferenceStore;
 import org.osgi.framework.Bundle;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.BundleEvent;
 import org.osgi.framework.BundleListener;
+import org.osgi.framework.FrameworkUtil;
 
 /**
  * Abstract base class for plug-ins that integrate with the Eclipse platform UI.
@@ -123,25 +112,6 @@ import org.osgi.framework.BundleListener;
  */
 public abstract class AbstractUIPlugin extends Plugin {
 
-	/**
-	 * The name of the dialog settings file (value
-	 * <code>"dialog_settings.xml"</code>).
-	 */
-	private static final String FN_DIALOG_SETTINGS = "dialog_settings.xml"; //$NON-NLS-1$
-
-	/**
-	 * Key used to allow dialog_settings.xml customization. The value is the root
-	 * url of the parent directory containing settings for different plug-ins. Each
-	 * plug-in dialog_settings.xml file should reside in the directory with the
-	 * plug-in name.
-	 */
-	private static final String KEY_DEFAULT_DIALOG_SETTINGS_ROOTURL = "default_dialog_settings_rootUrl"; //$NON-NLS-1$
-
-	/**
-	 * Storage for dialog and wizard data; <code>null</code> if not yet initialized.
-	 */
-	private IDialogSettings dialogSettings;
-
 	/**
 	 * Storage for preferences.
 	 */
@@ -204,24 +174,26 @@ public abstract class AbstractUIPlugin extends Plugin {
 	}
 
 	/**
-	 * Returns the dialog settings for this UI plug-in. The dialog settings is used
-	 * to hold persistent state data for the various wizards and dialogs of this
-	 * plug-in in the context of a workbench.
+	 * Returns the dialog settings by calling
+	 * {@link PlatformUI#getDialogSettingsProvider(Bundle)
+	 * PlatformUI.getDialogSettingsProvider}({@link #getBundle()
+	 * getBundle()}).{@link IDialogSettingsProvider#getDialogSettings()
+	 * getDialogSettings()}.
 	 * <p>
-	 * If an error occurs reading the dialog store, an empty one is quietly created
-	 * and returned.
-	 * </p>
-	 * <p>
-	 * Subclasses may override this method but are not expected to.
+	 * For new code, consider using the following idiom directly instead of relying
+	 * on a UI plugin class:
 	 * </p>
 	 *
+	 * <pre>
+	 * PlatformUI.getDialogSettingsProvider({@link FrameworkUtil#getBundle(Class) FrameworkUtil.getBundle}(My.class)).getDialogSettings()
+	 * </pre>
+	 *
 	 * @return the dialog settings
+	 * @see FrameworkUtil#getBundle(Class)
+	 * @see PlatformUI#getDialogSettingsProvider(Bundle)
 	 */
 	public IDialogSettings getDialogSettings() {
-		if (dialogSettings == null) {
-			loadDialogSettings();
-		}
-		return dialogSettings;
+		return PlatformUI.getDialogSettingsProvider(getBundle()).getDialogSettings();
 	}
 
 	/**
@@ -283,9 +255,12 @@ public abstract class AbstractUIPlugin extends Plugin {
 	 * This method exists as a convenience for plugin implementors. The workbench
 	 * can also be accessed by invoking <code>PlatformUI.getWorkbench()</code>.
 	 * </p>
-	 * 
+	 *
+	 * @deprecated Use {@link PlatformUI#getWorkbench()} directly
+	 *
 	 * @return IWorkbench the workbench for this plug-in
 	 */
+	@Deprecated
 	public IWorkbench getWorkbench() {
 		return PlatformUI.getWorkbench();
 	}
@@ -370,7 +345,7 @@ public abstract class AbstractUIPlugin extends Plugin {
 	 * <p>
 	 * Subclasses may override this method to fill the image registry.
 	 * </p>
-	 * 
+	 *
 	 * @param reg the registry to initialize
 	 *
 	 * @see #getImageRegistry
@@ -380,122 +355,17 @@ public abstract class AbstractUIPlugin extends Plugin {
 	}
 
 	/**
-	 * Loads the dialog settings for this plug-in. The default implementation first
-	 * looks for a standard named file in the plug-in's read/write state area; if no
-	 * such file exists, default product dialog settings directory (specified by
-	 * org.eclipse.ui/default_dialog_settings_rootUrl property) is checked to see if
-	 * there is a file with default plug-in dialog settings exists; if no such file
-	 * exists, the plug-in's install directory is checked to see if one was
-	 * installed with some default settings; if no file is found in either place, a
-	 * new empty dialog settings is created. If a problem occurs, an empty settings
-	 * is silently used.
-	 * <p>
+	 * Reloads the dialog settings for this bundle.
+	 *
 	 * This framework method may be overridden, although this is typically
 	 * unnecessary.
-	 * </p>
+	 *
+	 * @deprecated
+	 * @see PlatformUI#getDialogSettingsProvider(Bundle)
 	 */
+	@Deprecated
 	protected void loadDialogSettings() {
-		dialogSettings = createEmptySettings();
-		boolean loaded = loadDialogSettingsFromWorkspace();
-		// otherwise look for product custom dialog settings
-		if (!loaded) {
-			loaded = loadDefaultDialogSettingsFromProduct();
-		}
-		// otherwise look for bundle specific dialog settings
-		if (!loaded) {
-			loadDefaultDialogSettingsFromBundle();
-		}
-	}
-
-	/**
-	 * @return true if the product specific settings file was successfully read
-	 */
-	private boolean loadDefaultDialogSettingsFromProduct() {
-		String rootUrl = PlatformUI.getPreferenceStore().getString(KEY_DEFAULT_DIALOG_SETTINGS_ROOTURL);
-		if (rootUrl == null || rootUrl.isEmpty()) {
-			return false;
-		}
-		String bundlePart = getBundle().getSymbolicName() + "/" + FN_DIALOG_SETTINGS; //$NON-NLS-1$
-		String fullUrl = rootUrl.endsWith("/") ? rootUrl + bundlePart : rootUrl + "/" + bundlePart; //$NON-NLS-1$//$NON-NLS-2$
-		URL url;
-		try {
-			url = new URL(fullUrl);
-		} catch (MalformedURLException e) {
-			getLog().log(new Status(IStatus.ERROR, getBundle().getSymbolicName(),
-					"Failed to load dialog settings from: " + fullUrl, e)); //$NON-NLS-1$
-			return false;
-		}
-
-		try {
-			url = FileLocator.resolve(url);
-		} catch (IOException e) {
-			if (WorkbenchPlugin.DEBUG) {
-				getLog().log(new Status(IStatus.ERROR, getBundle().getSymbolicName(),
-						"Failed to load dialog settings from: " + fullUrl, e)); //$NON-NLS-1$
-			}
-			return false;
-		}
-
-		try (BufferedReader reader = new BufferedReader(
-				new InputStreamReader(url.openStream(), StandardCharsets.UTF_8))) {
-			dialogSettings.load(reader);
-			return true;
-		} catch (IOException e) {
-			// load failed so ensure we have an empty settings
-			dialogSettings = createEmptySettings();
-			getLog().log(new Status(IStatus.ERROR, getBundle().getSymbolicName(),
-					"Failed to load dialog settings from: " + url, e)); //$NON-NLS-1$
-		}
-		return false;
-	}
-
-	/**
-	 * @return true if the workspace settings file was successfully read
-	 */
-	private boolean loadDialogSettingsFromWorkspace() {
-		IPath dataLocation = getStateLocationOrNull();
-		if (dataLocation == null) {
-			// bug 69387: The instance area should not be created (in the call to
-			// #getStateLocation) if -data @none or -data @noDefault was used
-			return false;
-		}
-		// try r/w state area in the local file system
-		String readWritePath = dataLocation.append(FN_DIALOG_SETTINGS).toOSString();
-		File settingsFile = new File(readWritePath);
-		if (settingsFile.exists()) {
-			try {
-				dialogSettings.load(readWritePath);
-			} catch (IOException e) {
-				// load failed so ensure we have an empty settings
-				dialogSettings = createEmptySettings();
-				getLog().log(new Status(IStatus.ERROR, getBundle().getSymbolicName(),
-						"Failed to load dialog settings from: " + settingsFile, e)); //$NON-NLS-1$
-			}
-			return true;
-		}
-		return false;
-	}
-
-	private void loadDefaultDialogSettingsFromBundle() {
-		Bundle bundle = getBundle();
-		URL dsURL = BundleUtility.find(bundle, FN_DIALOG_SETTINGS);
-		if (dsURL == null) {
-			// no bundle defaults
-			return;
-		}
-		try (BufferedReader reader = new BufferedReader(
-				new InputStreamReader(dsURL.openStream(), StandardCharsets.UTF_8))) {
-			dialogSettings.load(reader);
-		} catch (IOException e) {
-			getLog().log(new Status(IStatus.ERROR, bundle.getSymbolicName(),
-					"Failed to load dialog settings from: " + dsURL, e)); //$NON-NLS-1$
-			// load failed so ensure we have an empty settings
-			dialogSettings = createEmptySettings();
-		}
-	}
-
-	private DialogSettings createEmptySettings() {
-		return new DialogSettings("Workbench"); //$NON-NLS-1$
+		PlatformUI.getDialogSettingsProvider(getBundle()).loadDialogSettings();
 	}
 
 	/**
@@ -536,30 +406,18 @@ public abstract class AbstractUIPlugin extends Plugin {
 		// startup() is not guaranteed to be called in the UI thread,
 		// but refreshPluginActions must run in the UI thread,
 		// so use asyncExec. See bug 6623 for more details.
-		Display.getDefault().asyncExec(() -> WWinPluginAction.refreshActionList());
+		Display.getDefault().asyncExec(WWinPluginAction::refreshActionList);
 	}
 
 	/**
-	 * Saves this plug-in's dialog settings. Any problems which arise are silently
-	 * ignored.
+	 * Dialog settings are saved automatically when the workbench stops.
+	 *
+	 * @deprecated
+	 * @see IDialogSettingsProvider#saveDialogSettings()
 	 */
+	@Deprecated
 	protected void saveDialogSettings() {
-		if (dialogSettings == null) {
-			return;
-		}
-
-		try {
-			IPath path = getStateLocationOrNull();
-			if (path == null) {
-				return;
-			}
-			String readWritePath = path.append(FN_DIALOG_SETTINGS).toOSString();
-			dialogSettings.save(readWritePath);
-		} catch (IOException e) {
-			// spec'ed to ignore problems
-		} catch (IllegalStateException e) {
-			// spec'ed to ignore problems
-		}
+		PlatformUI.getDialogSettingsProvider(getBundle()).saveDialogSettings();
 	}
 
 	/**
@@ -596,7 +454,7 @@ public abstract class AbstractUIPlugin extends Plugin {
 	 * The <code>AbstractUIPlugin</code> implementation of this <code>Plugin</code>
 	 * method does nothing. Subclasses may extend this method, but must send super
 	 * first.
-	 * 
+	 *
 	 * @deprecated In Eclipse 3.0, <code>shutdown</code> has been replaced by
 	 *             {@link Plugin#stop(BundleContext context)}. Implementations of
 	 *             <code>shutdown</code> should be changed to extend
@@ -677,7 +535,7 @@ public abstract class AbstractUIPlugin extends Plugin {
 			if (bundleListener != null) {
 				context.removeBundleListener(bundleListener);
 			}
-			saveDialogSettings();
+			// saveDialogSettings(); -> now done by DialogSettingsProvider
 			savePreferenceStore();
 			preferenceStore = null;
 			if (imageRegistry != null)
@@ -692,6 +550,18 @@ public abstract class AbstractUIPlugin extends Plugin {
 	 * Creates and returns a new image descriptor for an image file located within
 	 * the specified plug-in.
 	 * <p>
+	 * Prefer to use
+	 * {@link ResourceLocator#imageDescriptorFromBundle(String, String)} to create a
+	 * new {@link ImageDescriptor} for a file inside a bundle or
+	 * </p>
+	 * <p>
+	 * <code>ImageDescriptor imageDescriptor = PlatformUI.isWorkbenchRunning() ? PlatformUI.getWorkbench().getSharedImages().getImageDescriptor(imageSymbolicName) : null;</code>
+	 * </p>
+	 * <p>
+	 * to reuse already declared {@link ImageDescriptor} (refer to
+	 * {@link ISharedImages#getImageDescriptor(String)} for more details)
+	 * </p>
+	 * <p>
 	 * This is a convenience method that simply locates the image file in within the
 	 * plug-in. It will now query the ISharedImages registry first. The path is
 	 * relative to the root of the plug-in, and takes into account files coming from
@@ -708,74 +578,24 @@ public abstract class AbstractUIPlugin extends Plugin {
 	 *                      root of the plug-in; the path must be legal
 	 * @return an image descriptor, or <code>null</code> if no image could be found
 	 * @since 3.0
+	 *
 	 */
 	public static ImageDescriptor imageDescriptorFromPlugin(String pluginId, String imageFilePath) {
 		if (pluginId == null || imageFilePath == null) {
 			throw new IllegalArgumentException();
 		}
-
 		IWorkbench workbench = PlatformUI.isWorkbenchRunning() ? PlatformUI.getWorkbench() : null;
 		ImageDescriptor imageDescriptor = workbench == null ? null
 				: workbench.getSharedImages().getImageDescriptor(imageFilePath);
-		if (imageDescriptor != null)
+		if (imageDescriptor != null) {
 			return imageDescriptor; // found in the shared images
-
+		}
 		// if the bundle is not ready then there is no image
 		Bundle bundle = Platform.getBundle(pluginId);
 		if (!BundleUtility.isReady(bundle)) {
+
 			return null;
 		}
-
-		// Don't resolve the URL here, but create a URL using the
-		// "platform:/plugin" protocol, which also supports fragments.
-		// Caveat: The resulting URL may contain $nl$ etc., which is not
-		// directly supported by PlatformURLConnection and needs to go through
-		// FileLocator#find(URL), see bug 250432.
-		IPath uriPath = new Path("/plugin").append(pluginId).append(imageFilePath); //$NON-NLS-1$
-		URL url;
-		try {
-			URI uri = new URI("platform", null, uriPath.toString(), null); //$NON-NLS-1$
-			url = uri.toURL();
-		} catch (MalformedURLException | URISyntaxException e) {
-			return null;
-		}
-
-		// look for the image
-		URL fullPathString = FileLocator.find(url);
-		if (fullPathString == null) {
-			// If not found, reinterpret imageFilePath as full URL.
-			// This is unspecified, but apparently widely-used, see bug 395126.
-			try {
-				url = new URL(imageFilePath);
-			} catch (MalformedURLException e) {
-				return null;
-			}
-		}
-		// create image descriptor with the platform:/ URL
-		return ImageDescriptor.createFromURL(url);
+		return ResourceLocator.imageDescriptorFromBundle(pluginId, imageFilePath).orElse(null);
 	}
-
-	/**
-	 * FOR INTERNAL WORKBENCH USE ONLY.
-	 *
-	 * Returns the path to a location in the file system that can be used to
-	 * persist/restore state between workbench invocations. If the location did not
-	 * exist prior to this call it will be created. Returns <code>null</code> if no
-	 * such location is available.
-	 *
-	 * @return path to a location in the file system where this plug-in can persist
-	 *         data between sessions, or <code>null</code> if no such location is
-	 *         available.
-	 * @since 3.1
-	 */
-	private IPath getStateLocationOrNull() {
-		try {
-			return getStateLocation();
-		} catch (IllegalStateException e) {
-			// This occurs if -data=@none is explicitly specified, so ignore this silently.
-			// Is this OK? See bug 85071.
-			return null;
-		}
-	}
-
 }
