@@ -51,13 +51,12 @@ import org.osgi.service.prefs.BackingStoreException;
  * @see org.eclipse.core.runtime.preferences
  * @since 3.1
  */
-public class ScopedPreferenceStore extends EventManager implements
-		IPreferenceStore, IPersistentPreferenceStore {
+public class ScopedPreferenceStore extends EventManager implements IPreferenceStore, IPersistentPreferenceStore {
 
 	/**
-	 * The storeContext is the context where values will stored with the
-	 * setValue methods. If there are no searchContexts this will be the search
-	 * context. (along with the "default" context)
+	 * The storeContext is the context where values will stored with the setValue
+	 * methods. If there are no searchContexts this will be the search context.
+	 * (along with the "default" context)
 	 */
 	private IScopeContext storeContext;
 
@@ -73,14 +72,14 @@ public class ScopedPreferenceStore extends EventManager implements
 	protected boolean silentRunning = false;
 
 	/**
-	 * The listener on the IEclipsePreferences. This is used to forward updates
-	 * to the property change listeners on the preference store.
+	 * The listener on the IEclipsePreferences. This is used to forward updates to
+	 * the property change listeners on the preference store.
 	 */
 	IEclipsePreferences.IPreferenceChangeListener preferencesListener;
 
 	/**
-	 * The default context is the context where getDefault and setDefault
-	 * methods will search. This context is also used in the search.
+	 * The default context is the context where getDefault and setDefault methods
+	 * will search. This context is also used in the search.
 	 */
 	private IScopeContext defaultContext = DefaultScope.INSTANCE;
 
@@ -95,8 +94,7 @@ public class ScopedPreferenceStore extends EventManager implements
 	String defaultQualifier;
 
 	/**
-	 * Boolean value indicating whether or not this store has changes to be
-	 * saved.
+	 * Boolean value indicating whether or not this store has changes to be saved.
 	 */
 	private boolean dirty;
 
@@ -105,15 +103,11 @@ public class ScopedPreferenceStore extends EventManager implements
 	 * node looked up by qualifier. <strong>NOTE:</strong> Any instance of
 	 * ScopedPreferenceStore should call
 	 *
-	 * @param context
-	 *            the scope to store to
-	 * @param qualifier
-	 *            the qualifier used to look up the preference node
-	 * @param defaultQualifierPath
-	 *            the qualifier used when looking up the defaults
+	 * @param context              the scope to store to
+	 * @param qualifier            the qualifier used to look up the preference node
+	 * @param defaultQualifierPath the qualifier used when looking up the defaults
 	 */
-	public ScopedPreferenceStore(IScopeContext context, String qualifier,
-			String defaultQualifierPath) {
+	public ScopedPreferenceStore(IScopeContext context, String qualifier, String defaultQualifierPath) {
 		this(context, qualifier);
 		this.defaultQualifier = defaultQualifierPath;
 	}
@@ -122,18 +116,15 @@ public class ScopedPreferenceStore extends EventManager implements
 	 * Create a new instance of the receiver. Store the values in context in the
 	 * node looked up by qualifier.
 	 *
-	 * @param context
-	 *            the scope to store to
-	 * @param qualifier
-	 *            the qualifer used to look up the preference node
+	 * @param context   the scope to store to
+	 * @param qualifier the qualifer used to look up the preference node
 	 */
 	public ScopedPreferenceStore(IScopeContext context, String qualifier) {
 		storeContext = context;
 		this.nodeQualifier = qualifier;
 		this.defaultQualifier = qualifier;
 
-		((IEclipsePreferences) getStorePreferences().parent())
-				.addNodeChangeListener(getNodeChangeListener());
+		((IEclipsePreferences) getStorePreferences().parent()).addNodeChangeListener(getNodeChangeListener());
 	}
 
 	/**
@@ -146,10 +137,8 @@ public class ScopedPreferenceStore extends EventManager implements
 		return new IEclipsePreferences.INodeChangeListener() {
 			@Override
 			public void added(NodeChangeEvent event) {
-				if (nodeQualifier.equals(event.getChild().name())
-						&& isListenerAttached()) {
-					getStorePreferences().addPreferenceChangeListener(
-							preferencesListener);
+				if (nodeQualifier.equals(event.getChild().name()) && isListenerAttached()) {
+					getStorePreferences().addPreferenceChangeListener(preferencesListener);
 				}
 			}
 
@@ -181,22 +170,19 @@ public class ScopedPreferenceStore extends EventManager implements
 				}
 				firePropertyChangeEvent(event.getKey(), oldValue, newValue);
 			};
-			getStorePreferences().addPreferenceChangeListener(
-					preferencesListener);
+			getStorePreferences().addPreferenceChangeListener(preferencesListener);
 		}
 
 	}
 
 	/**
-	 * Does its best at determining the default value for the given key. Checks
-	 * the given object's type and then looks in the list of defaults to see if
-	 * a value exists. If not or if there is a problem converting the value, the
-	 * default default value for that type is returned.
+	 * Does its best at determining the default value for the given key. Checks the
+	 * given object's type and then looks in the list of defaults to see if a value
+	 * exists. If not or if there is a problem converting the value, the default
+	 * default value for that type is returned.
 	 *
-	 * @param key
-	 *            the key to search
-	 * @param obj
-	 *            the object who default we are looking for
+	 * @param key the key to search
+	 * @param obj the object who default we are looking for
 	 * @return Object or <code>null</code>
 	 */
 	Object getDefault(String key, Object obj) {
@@ -212,8 +198,7 @@ public class ScopedPreferenceStore extends EventManager implements
 		} else if (obj instanceof Long) {
 			return Long.valueOf(defaults.getLong(key, LONG_DEFAULT_DEFAULT));
 		} else if (obj instanceof Boolean) {
-			return defaults.getBoolean(key, BOOLEAN_DEFAULT_DEFAULT) ? Boolean.TRUE
-					: Boolean.FALSE;
+			return defaults.getBoolean(key, BOOLEAN_DEFAULT_DEFAULT) ? Boolean.TRUE : Boolean.FALSE;
 		} else {
 			return null;
 		}
@@ -246,16 +231,15 @@ public class ScopedPreferenceStore extends EventManager implements
 
 	/**
 	 * Return the preference path to search preferences on. This is the list of
-	 * preference nodes based on the scope contexts for this store. If there are
-	 * no search contexts set, then return this store's context.
+	 * preference nodes based on the scope contexts for this store. If there are no
+	 * search contexts set, then return this store's context.
 	 * <p>
-	 * Whether or not the default context should be included in the resulting
-	 * list is specified by the <code>includeDefault</code> parameter.
+	 * Whether or not the default context should be included in the resulting list
+	 * is specified by the <code>includeDefault</code> parameter.
 	 * </p>
 	 *
-	 * @param includeDefault
-	 *            <code>true</code> if the default context should be included
-	 *            and <code>false</code> otherwise
+	 * @param includeDefault <code>true</code> if the default context should be
+	 *                       included and <code>false</code> otherwise
 	 * @return IEclipsePreferences[]
 	 * @since 3.4 public, was added in 3.1 as private method
 	 */
@@ -264,8 +248,7 @@ public class ScopedPreferenceStore extends EventManager implements
 		// this store was created on. (and optionally the default)
 		if (searchContexts == null) {
 			if (includeDefault) {
-				return new IEclipsePreferences[] { getStorePreferences(),
-						getDefaultPreferences() };
+				return new IEclipsePreferences[] { getStorePreferences(), getDefaultPreferences() };
 			}
 			return new IEclipsePreferences[] { getStorePreferences() };
 		}
@@ -286,22 +269,21 @@ public class ScopedPreferenceStore extends EventManager implements
 	}
 
 	/**
-	 * Set the search contexts to scopes. When searching for a value the seach
-	 * will be done in the order of scope contexts and will not search the
-	 * storeContext unless it is in this list.
+	 * Set the search contexts to scopes. When searching for a value the seach will
+	 * be done in the order of scope contexts and will not search the storeContext
+	 * unless it is in this list.
 	 * <p>
 	 * If the given list is <code>null</code>, then clear this store's search
-	 * contexts. This means that only this store's scope context and default
-	 * scope will be used during preference value searching.
+	 * contexts. This means that only this store's scope context and default scope
+	 * will be used during preference value searching.
 	 * </p>
 	 * <p>
-	 * The defaultContext will be added to the end of this list automatically
-	 * and <em>MUST NOT</em> be included by the user.
+	 * The defaultContext will be added to the end of this list automatically and
+	 * <em>MUST NOT</em> be included by the user.
 	 * </p>
 	 *
-	 * @param scopes
-	 *            a list of scope contexts to use when searching, or
-	 *            <code>null</code>
+	 * @param scopes a list of scope contexts to use when searching, or
+	 *               <code>null</code>
 	 */
 	public void setSearchContexts(IScopeContext[] scopes) {
 		this.searchContexts = scopes;
@@ -313,10 +295,7 @@ public class ScopedPreferenceStore extends EventManager implements
 		// the end)
 		for (IScopeContext scope : scopes) {
 			if (scope.equals(defaultContext)) {
-				Assert
-						.isTrue(
-								false,
-								WorkbenchMessages.ScopedPreferenceStore_DefaultAddedError);
+				Assert.isTrue(false, WorkbenchMessages.ScopedPreferenceStore_DefaultAddedError);
 			}
 		}
 	}
@@ -326,13 +305,11 @@ public class ScopedPreferenceStore extends EventManager implements
 		if (name == null) {
 			return false;
 		}
-		return (Platform.getPreferencesService().get(name, null,
-				getPreferenceNodes(true))) != null;
+		return (Platform.getPreferencesService().get(name, null, getPreferenceNodes(true))) != null;
 	}
 
 	@Override
-	public void firePropertyChangeEvent(String name, Object oldValue,
-			Object newValue) {
+	public void firePropertyChangeEvent(String name, Object oldValue, Object newValue) {
 		// important: create intermediate array to protect against listeners
 		// being added/removed during the notification
 		final Object[] listeners = getListeners();
@@ -354,14 +331,12 @@ public class ScopedPreferenceStore extends EventManager implements
 	@Override
 	public boolean getBoolean(String name) {
 		String value = internalGet(name);
-		return value == null ? BOOLEAN_DEFAULT_DEFAULT : Boolean.valueOf(value)
-				.booleanValue();
+		return value == null ? BOOLEAN_DEFAULT_DEFAULT : Boolean.valueOf(value).booleanValue();
 	}
 
 	@Override
 	public boolean getDefaultBoolean(String name) {
-		return getDefaultPreferences()
-				.getBoolean(name, BOOLEAN_DEFAULT_DEFAULT);
+		return getDefaultPreferences().getBoolean(name, BOOLEAN_DEFAULT_DEFAULT);
 	}
 
 	@Override
@@ -403,17 +378,15 @@ public class ScopedPreferenceStore extends EventManager implements
 	}
 
 	/**
-	 * Return the string value for the specified key. Look in the nodes which
-	 * are specified by this object's list of search scopes. If the value does
-	 * not exist then return <code>null</code>.
+	 * Return the string value for the specified key. Look in the nodes which are
+	 * specified by this object's list of search scopes. If the value does not exist
+	 * then return <code>null</code>.
 	 *
-	 * @param key
-	 *            the key to search with
+	 * @param key the key to search with
 	 * @return String or <code>null</code> if the value does not exist.
 	 */
 	private String internalGet(String key) {
-		return Platform.getPreferencesService().get(key, null,
-				getPreferenceNodes(true));
+		return Platform.getPreferencesService().get(key, null, getPreferenceNodes(true));
 	}
 
 	@Override
@@ -466,8 +439,7 @@ public class ScopedPreferenceStore extends EventManager implements
 		if (name == null) {
 			return false;
 		}
-		return (Platform.getPreferencesService().get(name, null,
-				getPreferenceNodes(false))) == null;
+		return (Platform.getPreferencesService().get(name, null, getPreferenceNodes(false))) == null;
 	}
 
 	@Override
@@ -652,8 +624,8 @@ public class ScopedPreferenceStore extends EventManager implements
 				getStorePreferences().putBoolean(name, value);
 			}
 			dirty = true;
-			firePropertyChangeEvent(name, oldValue ? Boolean.TRUE
-					: Boolean.FALSE, value ? Boolean.TRUE : Boolean.FALSE);
+			firePropertyChangeEvent(name, oldValue ? Boolean.TRUE : Boolean.FALSE,
+					value ? Boolean.TRUE : Boolean.FALSE);
 		} finally {
 			silentRunning = false;// Restart listening to preferences
 		}
@@ -675,9 +647,8 @@ public class ScopedPreferenceStore extends EventManager implements
 	 */
 	private void disposePreferenceStoreListener() {
 
-		IEclipsePreferences root = (IEclipsePreferences) Platform
-				.getPreferencesService().getRootNode().node(
-						Plugin.PLUGIN_PREFERENCE_SCOPE);
+		IEclipsePreferences root = (IEclipsePreferences) Platform.getPreferencesService().getRootNode()
+				.node(Plugin.PLUGIN_PREFERENCE_SCOPE);
 		try {
 			if (!(root.nodeExists(nodeQualifier))) {
 				return;
