@@ -20,6 +20,7 @@ import org.eclipse.jface.dialogs.Dialog;
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.jface.resource.ImageDescriptor;
 import org.eclipse.jface.resource.ImageRegistry;
+import org.eclipse.jface.widgets.WidgetFactory;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.layout.FillLayout;
 import org.eclipse.swt.layout.GridData;
@@ -27,7 +28,6 @@ import org.eclipse.swt.widgets.Button;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Control;
 import org.eclipse.swt.widgets.Display;
-import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Shell;
 
 /**
@@ -70,8 +70,7 @@ public class Snippet057FileImageDescriptors {
 				if (registry == null) {
 					registry = new ImageRegistry(shell.getDisplay());
 				}
-				ImageDescriptor desc = registry.getDescriptor(path);
-				return desc;
+				return registry.getDescriptor(path);
 			}
 
 			@Override
@@ -94,9 +93,9 @@ public class Snippet057FileImageDescriptors {
 
 			@Override
 			protected Control createContents(Composite parent) {
-				Label label = new Label(parent, SWT.CENTER);
-				label.setText("Snippet057FileImageDescriptors");
-				label.setLayoutData(new GridData(SWT.FILL, SWT.NONE, true, false));
+				GridData layoutData = new GridData(SWT.FILL, SWT.NONE, true, false);
+				WidgetFactory.label(SWT.CENTER).text("Snippet057FileImageDescriptors").layoutData(layoutData)
+						.create(parent);
 				return super.createContents(parent);
 			}
 		};
