@@ -14,15 +14,13 @@
  *******************************************************************************/
 package org.eclipse.ui.examples.readmetool;
 
+import org.eclipse.core.resources.IFile;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IAdaptable;
 import org.eclipse.core.runtime.IConfigurationElement;
 import org.eclipse.core.runtime.IExtension;
 import org.eclipse.core.runtime.IExtensionPoint;
 import org.eclipse.core.runtime.Platform;
-
-import org.eclipse.core.resources.IFile;
-
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.IStructuredSelection;
 
@@ -52,8 +50,8 @@ public class ReadmeModelFactory {
 	protected void addSections(AdaptableList list, MarkElement element) {
 		list.add(element);
 		Object[] children = element.getChildren(element);
-		for (int i = 0; i < children.length; ++i) {
-			addSections(list, (MarkElement) children[i]);
+		for (Object child : children) {
+			addSections(list, (MarkElement) child);
 		}
 	}
 
@@ -145,14 +143,11 @@ public class ReadmeModelFactory {
 				// as a drop-down list. For the sake
 				// of simplicity, we will pick the last extension only.
 				if (i == extensions.length - 1) {
-					IConfigurationElement[] configElements = currentExtension
-							.getConfigurationElements();
-					for (int j = 0; j < configElements.length; j++) {
-						IConfigurationElement config = configElements[i];
-						if (config.getName()
-								.equals(IReadmeConstants.TAG_PARSER)) {
+					IConfigurationElement[] configElements = currentExtension.getConfigurationElements();
+					for (IConfigurationElement configElement : configElements) {
+						if (configElement.getName().equals(IReadmeConstants.TAG_PARSER)) {
 							// process the first 'parser' element and stop
-                            processParserElement(config);
+							processParserElement(configElement);
 							break;
 						}
 					}
