@@ -16,6 +16,7 @@
 package org.eclipse.e4.ui.tests.css.swt;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotEquals;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.graphics.FontData;
@@ -154,4 +155,17 @@ public class ButtonTest extends CSSSWTTestCase {
 		assertEquals(SWT.RIGHT, buttonToTest.getAlignment());
 	}
 
+	@Test
+	public void ensurePseudoAttributeAllowsToSelectionPushButton() {
+		Button buttonToTest = createTestButton("Button[style~='SWT.CHECK'] { background-color: #FF0000; color: #0000FF }");
+
+		assertEquals(RED, buttonToTest.getBackground().getRGB());
+		assertEquals(BLUE, buttonToTest.getForeground().getRGB());
+
+		Button unStyledButton = createTestButton("Button[style~='SWT.PUSH'] { background-color: #FF0000; color: #0000FF }");
+
+		assertNotEquals(RED, unStyledButton.getBackground().getRGB());
+		assertNotEquals(BLUE, unStyledButton.getForeground().getRGB());
+
+	}
 }
