@@ -242,6 +242,38 @@ public class MMenuItemTest {
 		assertTrue(menuItemWidget.getSelection());
 	}
 
+	@Test
+	public void testMDirectMenuItem_Check_Bug547050() {
+		MWindow window = ems.createModelElement(MWindow.class);
+		MMenu mainMenu = ems.createModelElement(MMenu.class);
+
+		MMenu fileMenu = ems.createModelElement(MMenu.class);
+		fileMenu.setElementId("file");
+		fileMenu.setLabel("File");
+		mainMenu.getChildren().add(fileMenu);
+
+		MMenuItem menuItem = ems.createModelElement(MDirectMenuItem.class);
+		fileMenu.getChildren().add(menuItem);
+		window.setMainMenu(mainMenu);
+
+		application.getChildren().add(window);
+		contextRule.createAndRunWorkbench(window);
+
+		MenuManager fileMenuManager = getRenderer(appContext, fileMenu).getManager(fileMenu);
+		Menu fileMenuWidget = fileMenuManager.getMenu();
+
+		// open menu to check if a direct menu item without contributing class is
+		// disabled by default
+		fileMenuWidget.notifyListeners(SWT.Show, null);
+
+		Object widget1 = menuItem.getWidget();
+		assertNotNull(widget1);
+		assertTrue(widget1 instanceof MenuItem);
+
+		MenuItem menuItemWidget = (MenuItem) widget1;
+		assertFalse(menuItemWidget.isEnabled());
+	}
+
 	@Test
 	public void testMHandledMenuItem_Check_Bug316752() {
 		MWindow window = ems.createModelElement(MWindow.class);
