@@ -28,9 +28,10 @@ import org.eclipse.core.runtime.Assert;
 public class ThreadRealm extends Realm {
 	private Thread thread;
 
-	private final LinkedList<Runnable> queue = new LinkedList<Runnable>();
+	private final LinkedList<Runnable> queue = new LinkedList<>();
 
 	private volatile boolean block;
+	private volatile boolean doProcess;
 
 	/**
 	 * Initializes the realm.
@@ -93,12 +94,15 @@ public class ThreadRealm extends Realm {
 
 		try {
 			synchronized (queue) {
+				doProcess = true;
+				queue.notifyAll();
 				while (!queue.isEmpty()) {
 					if (!block)
 						throw new IllegalStateException(
 								"Cannot process queue, ThreadRealm is not blocking on its thread");
 					queue.wait();
 				}
+				doProcess = false;
 			}
 		} catch (InterruptedException e) {
 			Thread.currentThread().interrupt();
@@ -131,10 +135,12 @@ public class ThreadRealm extends Realm {
 			while (block) {
 				Runnable runnable = null;
 				synchronized (queue) {
-					if (queue.isEmpty()) {
-						queue.wait();
-					} else {
-						runnable = queue.getFirst();
+					if (doProcess) { // ignore spurious wake-ups
+						if (queue.isEmpty()) {
+							queue.wait();
+						} else {
+							runnable = queue.getFirst();
+						}
 					}
 				}
 
