@@ -10,8 +10,6 @@
  ******************************************************************************/
 package org.eclipse.ui.tests.navigator.m12.model;
 import org.eclipse.core.resources.IResource;
-import org.eclipse.ui.tests.navigator.m12.model.M1Core;
-import org.eclipse.ui.tests.navigator.m12.model.ResourceWrapper;
 public class M1Resource extends ResourceWrapper {
 	public M1Resource(IResource resource) {
 		super(resource);
