@@ -13,9 +13,8 @@
  *******************************************************************************/
 package org.eclipse.ui.tests.performance.layout;
 
-import junit.framework.Assert;
+import static org.junit.Assert.assertNotNull;
 
-import org.eclipse.core.runtime.CoreException;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.ui.IWorkbenchPage;
@@ -24,6 +23,7 @@ import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.WorkbenchException;
 import org.eclipse.ui.tests.harness.util.UITestCase;
 
+
 /**
  * @since 3.1
  */
@@ -46,7 +46,7 @@ public class PerspectiveWidgetFactory extends TestWidgetFactory {
 		// open the perspective in a new window
 		window = PlatformUI.getWorkbench().openWorkbenchWindow(perspectiveId, UITestCase.getPageInput());
 		IWorkbenchPage page = window.getActivePage();
-		Assert.assertNotNull(page);
+		assertNotNull(page);
 	}
 
 	@Override
@@ -60,8 +60,7 @@ public class PerspectiveWidgetFactory extends TestWidgetFactory {
 	}
 
 	@Override
-	public void done() throws CoreException, WorkbenchException {
+	public void done() {
 		window.close();
-		super.done();
 	}
 }
