@@ -22,6 +22,8 @@ import org.eclipse.ui.IPartListener;
 import org.eclipse.ui.IPartListener2;
 import org.eclipse.ui.IPartService;
 import org.eclipse.ui.IPerspectiveDescriptor;
+import org.eclipse.ui.IViewPart;
+import org.eclipse.ui.IViewReference;
 import org.eclipse.ui.IWorkbenchPage;
 import org.eclipse.ui.IWorkbenchPart;
 import org.eclipse.ui.IWorkbenchPartReference;
@@ -549,51 +551,53 @@ public class IPartServiceTest extends UITestCase {
 		assertTrue(eventReceived[0]);
 	}
 
-//    /**
-//     * Tests that when a partOpened is received for a view being shown,
-//     * the view is available via findView, findViewReference, getViews and getViewReferences.
-//     *
-//     * @since 3.1
-//     */
-// This does not work as expected.  See bug 93784.
-//
-//    public void testViewFoundWhenOpened() throws Throwable {
-//    	final String viewId = MockViewPart.ID;
-//        final boolean[] eventReceived = { false, false };
-//        IPartListener listener = new TestPartListener() {
-//            public void partOpened(IWorkbenchPart part) {
-//                super.partOpened(part);
-//                // ensure that the notification is for the view we opened
-//                assertEquals(viewId, part.getSite().getId());
-//                // ensure that the view can be found
-//                assertNotNull(fPage.findView(viewId));
-//                IViewPart[] views = fPage.getViews();
-//                assertEquals(1, views.length);
-//                assertEquals(viewId, views[0].getSite().getId());
-//                eventReceived[0] = true;
-//            }
-//        };
-//        IPartListener2 listener2 = new TestPartListener2() {
-//            public void partOpened(IWorkbenchPartReference ref) {
-//                super.partOpened(ref);
-//                // ensure that the notification is for the view we opened
-//                assertEquals(viewId, ref.getId());
-//                // ensure that the view can be found
-//                assertNotNull(fPage.findViewReference(viewId));
-//                IViewReference[] refs = fPage.getViewReferences();
-//                assertEquals(1, refs.length);
-//                assertEquals(viewId, refs[0].getId());
-//                eventReceived[1] = true;
-//            }
-//        };
-//        fPage.addPartListener(listener);
-//        fPage.addPartListener(listener2);
-//        fPage.showView(viewId);
-//        fPage.removePartListener(listener);
-//        fPage.removePartListener(listener2);
-//        assertTrue(eventReceived[0]);
-//        assertTrue(eventReceived[1]);
-//    }
+	/**
+	 * Tests that when a partOpened is received for a view being shown, the view is
+	 * available via findView, findViewReference, getViews and getViewReferences.
+	 *
+	 * @since 3.1
+	 */
+	@Test
+	@Ignore("This does not work as expected.  See bug 93784.")
+	public void testViewFoundWhenOpened() throws Throwable {
+		final String viewId = MockViewPart.ID;
+		final boolean[] eventReceived = { false, false };
+		IPartListener listener = new TestPartListener() {
+			@Override
+			public void partOpened(IWorkbenchPart part) {
+				super.partOpened(part);
+				// ensure that the notification is for the view we opened
+				assertEquals(viewId, part.getSite().getId());
+				// ensure that the view can be found
+				assertNotNull(fPage.findView(viewId));
+				IViewPart[] views = fPage.getViews();
+				assertEquals(1, views.length);
+				assertEquals(viewId, views[0].getSite().getId());
+				eventReceived[0] = true;
+			}
+		};
+		IPartListener2 listener2 = new TestPartListener2() {
+			@Override
+			public void partOpened(IWorkbenchPartReference ref) {
+				super.partOpened(ref);
+				// ensure that the notification is for the view we opened
+				assertEquals(viewId, ref.getId());
+				// ensure that the view can be found
+				assertNotNull(fPage.findViewReference(viewId));
+				IViewReference[] refs = fPage.getViewReferences();
+				assertEquals(1, refs.length);
+				assertEquals(viewId, refs[0].getId());
+				eventReceived[1] = true;
+			}
+		};
+		fPage.addPartListener(listener);
+		fPage.addPartListener(listener2);
+		fPage.showView(viewId);
+		fPage.removePartListener(listener);
+		fPage.removePartListener(listener2);
+		assertTrue(eventReceived[0]);
+		assertTrue(eventReceived[1]);
+	}
 
 	/**
 	 * Tests that when a partOpened is received for an editor being opened,
