@@ -23,14 +23,9 @@ import org.eclipse.ui.internal.IWorkbenchHelpContextIds;
 import org.eclipse.ui.internal.WorkbenchPlugin;
 import org.eclipse.ui.tests.dialogs.PreferenceDialogWrapper;
 import org.eclipse.ui.tests.harness.util.DialogCheck;
+import org.junit.Test;
 
-import junit.framework.TestCase;
-
-public class UIComparePreferencesAuto extends TestCase {
-
-	public UIComparePreferencesAuto(String name) {
-		super(name);
-	}
+public class UIComparePreferencesAuto {
 
 	protected Shell getShell() {
 		return DialogCheck.getShell();
@@ -58,6 +53,7 @@ public class UIComparePreferencesAuto extends TestCase {
 		return dialog;
 	}
 
+	@Test
 	public void testCompareViewersPref() {
 		Dialog dialog = getPreferenceDialog("org.eclipse.compare.internal.ComparePreferencePage");
 		DialogCheck.assertDialogTexts(dialog);
