@@ -22,14 +22,9 @@ import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.internal.IWorkbenchHelpContextIds;
 import org.eclipse.ui.internal.WorkbenchPlugin;
 import org.eclipse.ui.tests.harness.util.DialogCheck;
+import org.junit.Test;
 
-import junit.framework.TestCase;
-
-public class DeprecatedUIPreferencesAuto extends TestCase {
-
-	public DeprecatedUIPreferencesAuto(String name) {
-		super(name);
-	}
+public class DeprecatedUIPreferencesAuto {
 
 	protected Shell getShell() {
 		return DialogCheck.getShell();
@@ -57,42 +52,50 @@ public class DeprecatedUIPreferencesAuto extends TestCase {
 		return dialog;
 	}
 
+	@Test
 	public void testWorkbenchPref() {
 		Dialog dialog = getPreferenceDialog("org.eclipse.ui.preferencePages.Workbench");
 		DialogCheck.assertDialogTexts(dialog);
 	}
 
+	@Test
 	public void testAppearancePref() {
 		Dialog dialog = getPreferenceDialog("org.eclipse.ui.preferencePages.Views");
 		DialogCheck.assertDialogTexts(dialog);
 	}
 
+	@Test
 	public void testDefaultTextEditorPref() {
 		Dialog dialog = getPreferenceDialog("org.eclipse.ui.preferencePages.TextEditor");
 		DialogCheck.assertDialogTexts(dialog);
 	}
 
+	@Test
 	public void testFileEditorsPref() {
 		Dialog dialog = getPreferenceDialog("org.eclipse.ui.preferencePages.FileEditors");
 		DialogCheck.assertDialogTexts(dialog);
 	}
 
+	@Test
 	public void testLocalHistoryPref() {
 		Dialog dialog = getPreferenceDialog("org.eclipse.ui.preferencePages.FileStates");
 		DialogCheck.assertDialogTexts(dialog);
 	}
 
+	@Test
 	public void testPerspectivesPref() {
 		Dialog dialog = getPreferenceDialog("org.eclipse.ui.preferencePages.Perspectives");
 		DialogCheck.assertDialogTexts(dialog);
 	}
 
 	//Only really checking if this opens without an exception
+	@Test
 	public void testFontEditorsPref() {
 		Dialog dialog = getPreferenceDialog("org.eclipse.ui.tests.dialogs.FontFieldEditorTestPreferencePage");
 		DialogCheck.assertDialogTexts(dialog);
 	}
 
+	@Test
 	public void testInfoProp() {
 		/*
 		 * Commented out because it generates a failure
@@ -104,6 +107,7 @@ public class DeprecatedUIPreferencesAuto extends TestCase {
 		 */
 	}
 
+	@Test
 	public void testProjectReferencesProp() {
 		/*
 		 * Commented out because it generates a failure
@@ -119,6 +123,7 @@ public class DeprecatedUIPreferencesAuto extends TestCase {
 	 * Test the editors preference page and toggle the
 	 * enable state twice to be sure there are no errors.
 	 */
+	@Test
 	public void testFieldEditorEnablePref() {
 
 		PreferenceDialogWrapper dialog = null;
