@@ -99,7 +99,7 @@ public abstract class UIWorkingSetWizardsAuto extends UITestCase {
 
 		} catch (CoreException e) {
 			TestPlugin.getDefault().getLog().log(e.getStatus());
-			fail();
+			fail(e.getMessage());
 			throw (e);
 
 		}
