@@ -29,8 +29,10 @@ import org.eclipse.ui.IWorkbenchCommandConstants;
 import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.handlers.IHandlerActivation;
 import org.eclipse.ui.handlers.IHandlerService;
+import org.junit.Ignore;
 import org.junit.Test;
 
+@Ignore("bug 275393")
 public class TextContentAssistCommandAdapterTest extends
 		AbstractContentAssistCommandAdapterTest {
 
