@@ -14,6 +14,8 @@
 
 package org.eclipse.ui.tests.keys;
 
+import static org.junit.Assert.assertEquals;
+
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.graphics.Font;
 import org.eclipse.swt.layout.GridData;
@@ -21,31 +23,23 @@ import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
-import org.eclipse.ui.tests.harness.util.UITestCase;
+import org.junit.After;
+import org.junit.Test;
 
 /**
  * Tests Bug 43597
  *
  * @since 3.0
  */
-public class Bug43597Test extends UITestCase {
+public class Bug43597Test {
 
 	private Font textFont;
 
-	/**
-	 * Constructor for Bug43597Test.
-	 *
-	 * @param name
-	 *            The name of the test
-	 */
-	public Bug43597Test(String name) {
-		super(name);
-	}
-
 	/**
 	 * Tests that setting the text on a text widget to an empty string does not
 	 * reset the font. This was a problem only on carbon.
 	 */
+	@Test
 	public void testFontReset() {
 		String metaCharacter = "\u2325X"; //$NON-NLS-1$
 
@@ -57,13 +51,13 @@ public class Bug43597Test extends UITestCase {
 		Text text = new Text(shell, SWT.LEFT);
 		textFont = new Font(text.getDisplay(),
 				"Lucida Grande", 13, SWT.NORMAL);
-		text.setFont(textFont); //$NON-NLS-1$
+		text.setFont(textFont);
 		text.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
 		shell.pack();
 		shell.open();
 
 		// Set the text once, and get the font.
-		text.setText(metaCharacter); //$NON-NLS-1$
+		text.setText(metaCharacter);
 		Font fontBefore = text.getFont();
 
 		// Set the font again, and get the font afterward.
@@ -79,11 +73,10 @@ public class Bug43597Test extends UITestCase {
 		shell.dispose();
 	}
 
-	@Override
-	protected void doTearDown() throws Exception {
+	@After
+	public void doTearDown() throws Exception {
 		if (textFont != null) {
 			textFont.dispose();
 		}
-		super.doTearDown();
 	}
 }
