@@ -13,6 +13,8 @@
  *******************************************************************************/
 package org.eclipse.ui.tests.preferences;
 
+import static org.junit.Assert.assertEquals;
+
 import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.jface.preference.PreferenceConverter;
 import org.eclipse.jface.resource.FontRegistry;
@@ -21,15 +23,14 @@ import org.eclipse.swt.graphics.FontData;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.ui.internal.WorkbenchPlugin;
 import org.eclipse.ui.plugin.AbstractUIPlugin;
-import org.eclipse.ui.tests.harness.util.UITestCase;
+import org.junit.Before;
+import org.junit.Test;
 
 /**
- * The FontPreferenceTestCase tests adding fonts to
- * the preference store and what occurs if the values
- * are bogus
+ * The FontPreferenceTestCase tests adding fonts to the preference store and
+ * what occurs if the values are bogus
  */
-
-public class DeprecatedFontPreferenceTestCase extends UITestCase {
+public class DeprecatedFontPreferenceTestCase {
 
 	public String BAD_FONT_DEFINITION = "BadFont-regular-10";
 
@@ -39,91 +40,71 @@ public class DeprecatedFontPreferenceTestCase extends UITestCase {
 
 	private IPreferenceStore preferenceStore;
 
-	/**
-	 * Constructor for FontPreferenceTestCase.
-	 * @param testName
-	 */
-	public DeprecatedFontPreferenceTestCase(String testName) {
-		super(testName);
-	}
-
-	@Override
-	protected void doSetUp() throws Exception {
-		super.doSetUp();
+	@Before
+	public void doSetUp() throws Exception {
 		AbstractUIPlugin plugin = WorkbenchPlugin.getDefault();
 		preferenceStore = plugin.getPreferenceStore();
 
-		//Set up the bogus entry for the bad first test
+		// Set up the bogus entry for the bad first test
 		FontData bogusData = new FontData();
 		bogusData.setName("BadData");
 		bogusData.setHeight(11);
 		FontData[] storedValue = new FontData[2];
 
-		//We assume here that the text font is OK
+		// We assume here that the text font is OK
 		storedValue[0] = bogusData;
-		storedValue[1] = (PreferenceConverter.getDefaultFontDataArray(
-				preferenceStore, JFaceResources.TEXT_FONT))[0];
-		PreferenceConverter
-				.setValue(preferenceStore, TEST_FONT_ID, storedValue);
-		PreferenceConverter.setDefault(preferenceStore, TEST_FONT_ID,
-				storedValue);
+		storedValue[1] = (PreferenceConverter.getDefaultFontDataArray(preferenceStore, JFaceResources.TEXT_FONT))[0];
+		PreferenceConverter.setValue(preferenceStore, TEST_FONT_ID, storedValue);
+		PreferenceConverter.setDefault(preferenceStore, TEST_FONT_ID, storedValue);
 	}
 
 	/**
-	 * Test for a valid font like the test font. The first good one
-	 * we should find should be the first one in the list.
+	 * Test for a valid font like the test font. The first good one we should find
+	 * should be the first one in the list.
 	 */
-
+	@Test
 	public void testGoodFontDefinition() {
 
 		FontRegistry fontRegistry = JFaceResources.getFontRegistry();
-		FontData[] currentTextFonts = PreferenceConverter.getFontDataArray(
-				preferenceStore, JFaceResources.TEXT_FONT);
-		FontData bestFont = fontRegistry.filterData(currentTextFonts, Display
-				.getCurrent())[0];
+		FontData[] currentTextFonts = PreferenceConverter.getFontDataArray(preferenceStore, JFaceResources.TEXT_FONT);
+		FontData bestFont = fontRegistry.filterData(currentTextFonts, Display.getCurrent())[0];
 
-		//Assert that it is the first font that we get as the
-		//valid one
+		// Assert that it is the first font that we get as the
+		// valid one
 		assertEquals(bestFont.getName(), currentTextFonts[0].getName());
 		assertEquals(bestFont.getHeight(), currentTextFonts[0].getHeight());
 	}
 
 	/**
-	 * Test that if the first font in the list is bad that the
-	 * second one comes back as valid.
+	 * Test that if the first font in the list is bad that the second one comes back
+	 * as valid.
 	 */
-
+	@Test
 	public void testBadFirstFontDefinition() {
 
 		FontRegistry fontRegistry = JFaceResources.getFontRegistry();
-		FontData[] currentTestFonts = PreferenceConverter.getFontDataArray(
-				preferenceStore, TEST_FONT_ID);
-		FontData bestFont = fontRegistry.filterData(currentTestFonts, Display
-				.getCurrent())[0];
+		FontData[] currentTestFonts = PreferenceConverter.getFontDataArray(preferenceStore, TEST_FONT_ID);
+		FontData bestFont = fontRegistry.filterData(currentTestFonts, Display.getCurrent())[0];
 
-		//Assert that it is the second font that we get as the
-		//valid one
+		// Assert that it is the second font that we get as the
+		// valid one
 		assertEquals(bestFont.getName(), currentTestFonts[1].getName());
 		assertEquals(bestFont.getHeight(), currentTestFonts[1].getHeight());
 	}
 
 	/**
-	 * Test that the no valid font is returned when the entry
-	 * is missing.
+	 * Test that the no valid font is returned when the entry is missing.
 	 */
-
+	@Test
 	public void testNoFontDefinition() {
 
 		FontRegistry fontRegistry = JFaceResources.getFontRegistry();
-		FontData[] currentTestFonts = PreferenceConverter.getFontDataArray(
-				preferenceStore, MISSING_FONT_ID);
-		FontData bestFont = fontRegistry.filterData(currentTestFonts, Display
-				.getCurrent())[0];
+		FontData[] currentTestFonts = PreferenceConverter.getFontDataArray(preferenceStore, MISSING_FONT_ID);
+		FontData bestFont = fontRegistry.filterData(currentTestFonts, Display.getCurrent())[0];
 
-		FontData[] systemFontData = Display.getCurrent().getSystemFont()
-				.getFontData();
+		FontData[] systemFontData = Display.getCurrent().getSystemFont().getFontData();
 
-		//Assert that the first font is the system font
+		// Assert that the first font is the system font
 		assertEquals(bestFont.getName(), systemFontData[0].getName());
 		assertEquals(bestFont.getHeight(), systemFontData[0].getHeight());
 	}
