@@ -237,11 +237,8 @@ public class PluginActivationTests {
 				if (b.getState() != Bundle.ACTIVE) {
 					System.out.println(b.getSymbolicName());
 				}
-			} else {
-				if (b.getState() == Bundle.ACTIVE) {
-					System.out.println(b.getSymbolicName());
-				}
-
+			} else if (b.getState() == Bundle.ACTIVE) {
+				System.out.println(b.getSymbolicName());
 			}
 
 		}
