@@ -13,29 +13,21 @@
  *******************************************************************************/
 package org.eclipse.ui.tests.zoom;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import org.junit.Ignore;
+import org.junit.runner.RunWith;
+import org.junit.runners.Suite;
 
 /**
  * A test suite to test the zooming behavior of Eclipse.
  */
-public class ZoomTestSuite extends TestSuite {
-	/**
-	 * Returns the suite.  This is required to
-	 * use the JUnit Launcher.
-	 */
-	public static Test suite() {
-		return new ZoomTestSuite();
-	}
-
-	/**
-	 * Construct the test suite.
-	 */
-	public ZoomTestSuite() {
-		addTest(new TestSuite(ZoomedViewActivateTest.class));
-		addTest(new TestSuite(ZoomedEditorCloseTest.class));
-		addTest(new TestSuite(ZoomedViewCloseTest.class));
-		addTest(new TestSuite(ShowViewTest.class));
-		addTest(new TestSuite(OpenEditorTest.class));
-	}
+@Ignore
+@RunWith(Suite.class)
+@Suite.SuiteClasses({
+	ZoomedViewActivateTest.class,
+	ZoomedEditorCloseTest.class,
+	ZoomedViewCloseTest.class,
+	ShowViewTest.class,
+	OpenEditorTest.class,
+})
+public class ZoomTestSuite {
 }
